# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: github.com/metaprov/modelaapi/services/entity/v1/entity.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1 import generated_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n=github.com/metaprov/modelaapi/services/entity/v1/entity.proto\x12\x30github.com.metaprov.modelaapi.services.entity.v1\x1a google/protobuf/field_mask.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x44github.com/metaprov/modelaapi/pkg/apis/data/v1alpha1/generated.proto\"\xf3\x01\n\x13ListEntitiesRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x61\n\x06labels\x18\x02 \x03(\x0b\x32Q.github.com.metaprov.modelaapi.services.entity.v1.ListEntitiesRequest.LabelsEntry\x12\x11\n\tpage_size\x18\x03 \x01(\x05\x12\x12\n\npage_token\x18\x04 \x01(\t\x12\x10\n\x08order_by\x18\x05 \x01(\t\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x83\x01\n\x14ListEntitiesResponse\x12R\n\x08\x65ntities\x18\x01 \x01(\x0b\x32@.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.EntityList\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"c\n\x13\x43reateEntityRequest\x12L\n\x06\x65ntity\x18\x01 \x01(\x0b\x32<.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Entity\"\x16\n\x14\x43reateEntityResponse\"\x93\x01\n\x13UpdateEntityRequest\x12L\n\x06\x65ntity\x18\x01 \x01(\x0b\x32<.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Entity\x12.\n\nfield_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\"\x16\n\x14UpdateEntityResponse\"c\n\x10GetEntityRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12.\n\nfield_mask\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\"o\n\x11GetEntityResponse\x12L\n\x06\x65ntity\x18\x01 \x01(\x0b\x32<.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Entity\x12\x0c\n\x04yaml\x18\x02 \x01(\t\"6\n\x13\x44\x65leteEntityRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x16\n\x14\x44\x65leteEntityResponse2\xf3\x07\n\rEntityService\x12\xbf\x01\n\x0cListEntities\x12\x45.github.com.metaprov.modelaapi.services.entity.v1.ListEntitiesRequest\x1a\x46.github.com.metaprov.modelaapi.services.entity.v1.ListEntitiesResponse\" \x82\xd3\xe4\x93\x02\x1a\x12\x18/v1/entities/{namespace}\x12\xb6\x01\n\x0c\x43reateEntity\x12\x45.github.com.metaprov.modelaapi.services.entity.v1.CreateEntityRequest\x1a\x46.github.com.metaprov.modelaapi.services.entity.v1.CreateEntityResponse\"\x17\x82\xd3\xe4\x93\x02\x11\"\x0c/v1/entities:\x01*\x12\xb1\x01\n\tGetEntity\x12\x42.github.com.metaprov.modelaapi.services.entity.v1.GetEntityRequest\x1a\x43.github.com.metaprov.modelaapi.services.entity.v1.GetEntityResponse\"\x1b\x82\xd3\xe4\x93\x02\x15\x12\x13/v1/entities/{name}\x12\xe9\x01\n\x0cUpdateEntity\x12\x45.github.com.metaprov.modelaapi.services.entity.v1.UpdateEntityRequest\x1a\x46.github.com.metaprov.modelaapi.services.entity.v1.UpdateEntityResponse\"J\x82\xd3\xe4\x93\x02\x44\x1a?/v1/entities/{entity.metadata.namespace}/{entity.metadata.name}:\x01*\x12\xc6\x01\n\x0c\x44\x65leteEntity\x12\x45.github.com.metaprov.modelaapi.services.entity.v1.DeleteEntityRequest\x1a\x46.github.com.metaprov.modelaapi.services.entity.v1.DeleteEntityResponse\"\'\x82\xd3\xe4\x93\x02!*\x1f/v1/entities/{namespace}/{name}B2Z0github.com/metaprov/modelaapi/services/entity/v1b\x06proto3')



_LISTENTITIESREQUEST = DESCRIPTOR.message_types_by_name['ListEntitiesRequest']
_LISTENTITIESREQUEST_LABELSENTRY = _LISTENTITIESREQUEST.nested_types_by_name['LabelsEntry']
_LISTENTITIESRESPONSE = DESCRIPTOR.message_types_by_name['ListEntitiesResponse']
_CREATEENTITYREQUEST = DESCRIPTOR.message_types_by_name['CreateEntityRequest']
_CREATEENTITYRESPONSE = DESCRIPTOR.message_types_by_name['CreateEntityResponse']
_UPDATEENTITYREQUEST = DESCRIPTOR.message_types_by_name['UpdateEntityRequest']
_UPDATEENTITYRESPONSE = DESCRIPTOR.message_types_by_name['UpdateEntityResponse']
_GETENTITYREQUEST = DESCRIPTOR.message_types_by_name['GetEntityRequest']
_GETENTITYRESPONSE = DESCRIPTOR.message_types_by_name['GetEntityResponse']
_DELETEENTITYREQUEST = DESCRIPTOR.message_types_by_name['DeleteEntityRequest']
_DELETEENTITYRESPONSE = DESCRIPTOR.message_types_by_name['DeleteEntityResponse']
ListEntitiesRequest = _reflection.GeneratedProtocolMessageType('ListEntitiesRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _LISTENTITIESREQUEST_LABELSENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.entity.v1.entity_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.entity.v1.ListEntitiesRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _LISTENTITIESREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.entity.v1.entity_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.entity.v1.ListEntitiesRequest)
  })
_sym_db.RegisterMessage(ListEntitiesRequest)
_sym_db.RegisterMessage(ListEntitiesRequest.LabelsEntry)

ListEntitiesResponse = _reflection.GeneratedProtocolMessageType('ListEntitiesResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTENTITIESRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.entity.v1.entity_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.entity.v1.ListEntitiesResponse)
  })
_sym_db.RegisterMessage(ListEntitiesResponse)

CreateEntityRequest = _reflection.GeneratedProtocolMessageType('CreateEntityRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEENTITYREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.entity.v1.entity_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.entity.v1.CreateEntityRequest)
  })
_sym_db.RegisterMessage(CreateEntityRequest)

CreateEntityResponse = _reflection.GeneratedProtocolMessageType('CreateEntityResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATEENTITYRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.entity.v1.entity_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.entity.v1.CreateEntityResponse)
  })
_sym_db.RegisterMessage(CreateEntityResponse)

UpdateEntityRequest = _reflection.GeneratedProtocolMessageType('UpdateEntityRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEENTITYREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.entity.v1.entity_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.entity.v1.UpdateEntityRequest)
  })
_sym_db.RegisterMessage(UpdateEntityRequest)

UpdateEntityResponse = _reflection.GeneratedProtocolMessageType('UpdateEntityResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEENTITYRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.entity.v1.entity_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.entity.v1.UpdateEntityResponse)
  })
_sym_db.RegisterMessage(UpdateEntityResponse)

GetEntityRequest = _reflection.GeneratedProtocolMessageType('GetEntityRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETENTITYREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.entity.v1.entity_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.entity.v1.GetEntityRequest)
  })
_sym_db.RegisterMessage(GetEntityRequest)

GetEntityResponse = _reflection.GeneratedProtocolMessageType('GetEntityResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETENTITYRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.entity.v1.entity_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.entity.v1.GetEntityResponse)
  })
_sym_db.RegisterMessage(GetEntityResponse)

DeleteEntityRequest = _reflection.GeneratedProtocolMessageType('DeleteEntityRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEENTITYREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.entity.v1.entity_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.entity.v1.DeleteEntityRequest)
  })
_sym_db.RegisterMessage(DeleteEntityRequest)

DeleteEntityResponse = _reflection.GeneratedProtocolMessageType('DeleteEntityResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETEENTITYRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.entity.v1.entity_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.entity.v1.DeleteEntityResponse)
  })
_sym_db.RegisterMessage(DeleteEntityResponse)

_ENTITYSERVICE = DESCRIPTOR.services_by_name['EntityService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z0github.com/metaprov/modelaapi/services/entity/v1'
  _LISTENTITIESREQUEST_LABELSENTRY._options = None
  _LISTENTITIESREQUEST_LABELSENTRY._serialized_options = b'8\001'
  _ENTITYSERVICE.methods_by_name['ListEntities']._options = None
  _ENTITYSERVICE.methods_by_name['ListEntities']._serialized_options = b'\202\323\344\223\002\032\022\030/v1/entities/{namespace}'
  _ENTITYSERVICE.methods_by_name['CreateEntity']._options = None
  _ENTITYSERVICE.methods_by_name['CreateEntity']._serialized_options = b'\202\323\344\223\002\021\"\014/v1/entities:\001*'
  _ENTITYSERVICE.methods_by_name['GetEntity']._options = None
  _ENTITYSERVICE.methods_by_name['GetEntity']._serialized_options = b'\202\323\344\223\002\025\022\023/v1/entities/{name}'
  _ENTITYSERVICE.methods_by_name['UpdateEntity']._options = None
  _ENTITYSERVICE.methods_by_name['UpdateEntity']._serialized_options = b'\202\323\344\223\002D\032?/v1/entities/{entity.metadata.namespace}/{entity.metadata.name}:\001*'
  _ENTITYSERVICE.methods_by_name['DeleteEntity']._options = None
  _ENTITYSERVICE.methods_by_name['DeleteEntity']._serialized_options = b'\202\323\344\223\002!*\037/v1/entities/{namespace}/{name}'
  _LISTENTITIESREQUEST._serialized_start=250
  _LISTENTITIESREQUEST._serialized_end=493
  _LISTENTITIESREQUEST_LABELSENTRY._serialized_start=448
  _LISTENTITIESREQUEST_LABELSENTRY._serialized_end=493
  _LISTENTITIESRESPONSE._serialized_start=496
  _LISTENTITIESRESPONSE._serialized_end=627
  _CREATEENTITYREQUEST._serialized_start=629
  _CREATEENTITYREQUEST._serialized_end=728
  _CREATEENTITYRESPONSE._serialized_start=730
  _CREATEENTITYRESPONSE._serialized_end=752
  _UPDATEENTITYREQUEST._serialized_start=755
  _UPDATEENTITYREQUEST._serialized_end=902
  _UPDATEENTITYRESPONSE._serialized_start=904
  _UPDATEENTITYRESPONSE._serialized_end=926
  _GETENTITYREQUEST._serialized_start=928
  _GETENTITYREQUEST._serialized_end=1027
  _GETENTITYRESPONSE._serialized_start=1029
  _GETENTITYRESPONSE._serialized_end=1140
  _DELETEENTITYREQUEST._serialized_start=1142
  _DELETEENTITYREQUEST._serialized_end=1196
  _DELETEENTITYRESPONSE._serialized_start=1198
  _DELETEENTITYRESPONSE._serialized_end=1220
  _ENTITYSERVICE._serialized_start=1223
  _ENTITYSERVICE._serialized_end=2234
# @@protoc_insertion_point(module_scope)
