# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from github.com.metaprov.modelaapi.services.datapipelinerun.v1 import datapipelinerun_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_datapipelinerun_dot_v1_dot_datapipelinerun__pb2


class DataPipelineRunServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.ListDataPipelineRuns = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.datapipelinerun.v1.DataPipelineRunService/ListDataPipelineRuns',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_datapipelinerun_dot_v1_dot_datapipelinerun__pb2.ListDataPipelineRunRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_datapipelinerun_dot_v1_dot_datapipelinerun__pb2.ListDataPipelineRunResponse.FromString,
                )
        self.CreateDataPipelineRun = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.datapipelinerun.v1.DataPipelineRunService/CreateDataPipelineRun',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_datapipelinerun_dot_v1_dot_datapipelinerun__pb2.CreateDataPipelineRunRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_datapipelinerun_dot_v1_dot_datapipelinerun__pb2.CreateDataPipelineRunResponse.FromString,
                )
        self.GetDataPipelineRun = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.datapipelinerun.v1.DataPipelineRunService/GetDataPipelineRun',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_datapipelinerun_dot_v1_dot_datapipelinerun__pb2.GetDataPipelineRunRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_datapipelinerun_dot_v1_dot_datapipelinerun__pb2.GetDataPipelineRunResponse.FromString,
                )
        self.UpdateDataPipelineRun = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.datapipelinerun.v1.DataPipelineRunService/UpdateDataPipelineRun',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_datapipelinerun_dot_v1_dot_datapipelinerun__pb2.UpdateDataPipelineRunRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_datapipelinerun_dot_v1_dot_datapipelinerun__pb2.UpdateDataPipelineRunResponse.FromString,
                )
        self.DeleteDataPipelineRun = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.datapipelinerun.v1.DataPipelineRunService/DeleteDataPipelineRun',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_datapipelinerun_dot_v1_dot_datapipelinerun__pb2.DeleteDataPipelineRunRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_datapipelinerun_dot_v1_dot_datapipelinerun__pb2.DeleteDataPipelineRunResponse.FromString,
                )
        self.AbortDataPipelineRun = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.datapipelinerun.v1.DataPipelineRunService/AbortDataPipelineRun',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_datapipelinerun_dot_v1_dot_datapipelinerun__pb2.AbortDataPipelineRunRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_datapipelinerun_dot_v1_dot_datapipelinerun__pb2.AbortDataPipelineRunResponse.FromString,
                )
        self.PauseDataPipelineRun = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.datapipelinerun.v1.DataPipelineRunService/PauseDataPipelineRun',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_datapipelinerun_dot_v1_dot_datapipelinerun__pb2.PauseDataPipelineRunRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_datapipelinerun_dot_v1_dot_datapipelinerun__pb2.PauseDataPipelineRunResponse.FromString,
                )
        self.ResumeDataPipelineRun = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.datapipelinerun.v1.DataPipelineRunService/ResumeDataPipelineRun',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_datapipelinerun_dot_v1_dot_datapipelinerun__pb2.ResumeDataPipelineRunRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_datapipelinerun_dot_v1_dot_datapipelinerun__pb2.ResumeDataPipelineRunResponse.FromString,
                )


class DataPipelineRunServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def ListDataPipelineRuns(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateDataPipelineRun(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetDataPipelineRun(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateDataPipelineRun(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteDataPipelineRun(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AbortDataPipelineRun(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def PauseDataPipelineRun(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ResumeDataPipelineRun(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_DataPipelineRunServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'ListDataPipelineRuns': grpc.unary_unary_rpc_method_handler(
                    servicer.ListDataPipelineRuns,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_datapipelinerun_dot_v1_dot_datapipelinerun__pb2.ListDataPipelineRunRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_datapipelinerun_dot_v1_dot_datapipelinerun__pb2.ListDataPipelineRunResponse.SerializeToString,
            ),
            'CreateDataPipelineRun': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateDataPipelineRun,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_datapipelinerun_dot_v1_dot_datapipelinerun__pb2.CreateDataPipelineRunRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_datapipelinerun_dot_v1_dot_datapipelinerun__pb2.CreateDataPipelineRunResponse.SerializeToString,
            ),
            'GetDataPipelineRun': grpc.unary_unary_rpc_method_handler(
                    servicer.GetDataPipelineRun,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_datapipelinerun_dot_v1_dot_datapipelinerun__pb2.GetDataPipelineRunRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_datapipelinerun_dot_v1_dot_datapipelinerun__pb2.GetDataPipelineRunResponse.SerializeToString,
            ),
            'UpdateDataPipelineRun': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateDataPipelineRun,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_datapipelinerun_dot_v1_dot_datapipelinerun__pb2.UpdateDataPipelineRunRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_datapipelinerun_dot_v1_dot_datapipelinerun__pb2.UpdateDataPipelineRunResponse.SerializeToString,
            ),
            'DeleteDataPipelineRun': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteDataPipelineRun,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_datapipelinerun_dot_v1_dot_datapipelinerun__pb2.DeleteDataPipelineRunRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_datapipelinerun_dot_v1_dot_datapipelinerun__pb2.DeleteDataPipelineRunResponse.SerializeToString,
            ),
            'AbortDataPipelineRun': grpc.unary_unary_rpc_method_handler(
                    servicer.AbortDataPipelineRun,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_datapipelinerun_dot_v1_dot_datapipelinerun__pb2.AbortDataPipelineRunRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_datapipelinerun_dot_v1_dot_datapipelinerun__pb2.AbortDataPipelineRunResponse.SerializeToString,
            ),
            'PauseDataPipelineRun': grpc.unary_unary_rpc_method_handler(
                    servicer.PauseDataPipelineRun,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_datapipelinerun_dot_v1_dot_datapipelinerun__pb2.PauseDataPipelineRunRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_datapipelinerun_dot_v1_dot_datapipelinerun__pb2.PauseDataPipelineRunResponse.SerializeToString,
            ),
            'ResumeDataPipelineRun': grpc.unary_unary_rpc_method_handler(
                    servicer.ResumeDataPipelineRun,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_datapipelinerun_dot_v1_dot_datapipelinerun__pb2.ResumeDataPipelineRunRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_datapipelinerun_dot_v1_dot_datapipelinerun__pb2.ResumeDataPipelineRunResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'github.com.metaprov.modelaapi.services.datapipelinerun.v1.DataPipelineRunService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class DataPipelineRunService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def ListDataPipelineRuns(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.datapipelinerun.v1.DataPipelineRunService/ListDataPipelineRuns',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_datapipelinerun_dot_v1_dot_datapipelinerun__pb2.ListDataPipelineRunRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_datapipelinerun_dot_v1_dot_datapipelinerun__pb2.ListDataPipelineRunResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateDataPipelineRun(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.datapipelinerun.v1.DataPipelineRunService/CreateDataPipelineRun',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_datapipelinerun_dot_v1_dot_datapipelinerun__pb2.CreateDataPipelineRunRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_datapipelinerun_dot_v1_dot_datapipelinerun__pb2.CreateDataPipelineRunResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetDataPipelineRun(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.datapipelinerun.v1.DataPipelineRunService/GetDataPipelineRun',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_datapipelinerun_dot_v1_dot_datapipelinerun__pb2.GetDataPipelineRunRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_datapipelinerun_dot_v1_dot_datapipelinerun__pb2.GetDataPipelineRunResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateDataPipelineRun(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.datapipelinerun.v1.DataPipelineRunService/UpdateDataPipelineRun',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_datapipelinerun_dot_v1_dot_datapipelinerun__pb2.UpdateDataPipelineRunRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_datapipelinerun_dot_v1_dot_datapipelinerun__pb2.UpdateDataPipelineRunResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteDataPipelineRun(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.datapipelinerun.v1.DataPipelineRunService/DeleteDataPipelineRun',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_datapipelinerun_dot_v1_dot_datapipelinerun__pb2.DeleteDataPipelineRunRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_datapipelinerun_dot_v1_dot_datapipelinerun__pb2.DeleteDataPipelineRunResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def AbortDataPipelineRun(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.datapipelinerun.v1.DataPipelineRunService/AbortDataPipelineRun',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_datapipelinerun_dot_v1_dot_datapipelinerun__pb2.AbortDataPipelineRunRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_datapipelinerun_dot_v1_dot_datapipelinerun__pb2.AbortDataPipelineRunResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def PauseDataPipelineRun(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.datapipelinerun.v1.DataPipelineRunService/PauseDataPipelineRun',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_datapipelinerun_dot_v1_dot_datapipelinerun__pb2.PauseDataPipelineRunRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_datapipelinerun_dot_v1_dot_datapipelinerun__pb2.PauseDataPipelineRunResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ResumeDataPipelineRun(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.datapipelinerun.v1.DataPipelineRunService/ResumeDataPipelineRun',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_datapipelinerun_dot_v1_dot_datapipelinerun__pb2.ResumeDataPipelineRunRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_datapipelinerun_dot_v1_dot_datapipelinerun__pb2.ResumeDataPipelineRunResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
