# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: github.com/metaprov/modelaapi/pkg/apis/team/v1alpha1/generated.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from k8s.io.api.core.v1 import generated_pb2 as k8s_dot_io_dot_api_dot_core_dot_v1_dot_generated__pb2
from k8s.io.apimachinery.pkg.apis.meta.v1 import generated_pb2 as k8s_dot_io_dot_apimachinery_dot_pkg_dot_apis_dot_meta_dot_v1_dot_generated__pb2
from k8s.io.apimachinery.pkg.runtime import generated_pb2 as k8s_dot_io_dot_apimachinery_dot_pkg_dot_runtime_dot_generated__pb2
from k8s.io.apimachinery.pkg.runtime.schema import generated_pb2 as k8s_dot_io_dot_apimachinery_dot_pkg_dot_runtime_dot_schema_dot_generated__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nDgithub.com/metaprov/modelaapi/pkg/apis/team/v1alpha1/generated.proto\x12\x34github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1\x1a\"k8s.io/api/core/v1/generated.proto\x1a\x34k8s.io/apimachinery/pkg/apis/meta/v1/generated.proto\x1a/k8s.io/apimachinery/pkg/runtime/generated.proto\x1a\x36k8s.io/apimachinery/pkg/runtime/schema/generated.proto\"n\n\rCheckListItem\x12\x13\n\x0binstruction\x18\x01 \x01(\t\x12\x0f\n\x07\x65nabled\x18\x02 \x01(\x08\x12\x10\n\x08location\x18\x03 \x01(\t\x12\x11\n\tcondition\x18\x04 \x01(\t\x12\x12\n\nattachment\x18\x05 \x01(\t\"\x92\x02\n\x07\x43omment\x12\n\n\x02id\x18\x01 \x01(\t\x12\x36\n\tauthorRef\x18\x02 \x01(\x0b\x32#.k8s.io.api.core.v1.ObjectReference\x12\x0f\n\x07replyTo\x18\x03 \x01(\t\x12\x0f\n\x07\x63ontent\x18\x04 \x01(\t\x12<\n\x08postedAt\x18\x05 \x01(\x0b\x32*.k8s.io.apimachinery.pkg.apis.meta.v1.Time\x12\x0c\n\x04sent\x18\x06 \x01(\x08\x12\x0e\n\x06pinned\x18\x07 \x01(\x08\x12\x19\n\x11replyIndicationID\x18\x08 \x01(\t\x12\x10\n\x08imageURL\x18\t \x01(\t\x12\x18\n\x10\x61\x63\x63ountMentionID\x18\n \x01(\t\"\xf3\x01\n\x07Meeting\x12\x42\n\x08metadata\x18\x01 \x01(\x0b\x32\x30.k8s.io.apimachinery.pkg.apis.meta.v1.ObjectMeta\x12O\n\x04spec\x18\x02 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.MeetingSpec\x12S\n\x06status\x18\x03 \x01(\x0b\x32\x43.github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.MeetingStatus\"\x99\x01\n\x10MeetingCondition\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\x0e\n\x06status\x18\x02 \x01(\t\x12\x46\n\x12lastTransitionTime\x18\x03 \x01(\x0b\x32*.k8s.io.apimachinery.pkg.apis.meta.v1.Time\x12\x0e\n\x06reason\x18\x04 \x01(\t\x12\x0f\n\x07message\x18\x05 \x01(\t\"\x9d\x01\n\x0bMeetingList\x12@\n\x08metadata\x18\x01 \x01(\x0b\x32..k8s.io.apimachinery.pkg.apis.meta.v1.ListMeta\x12L\n\x05items\x18\x02 \x03(\x0b\x32=.github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.Meeting\"\x9d\x02\n\x0bMeetingSpec\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x0e\n\x06\x61genda\x18\x02 \x01(\t\x12\x36\n\tentityRef\x18\x03 \x01(\x0b\x32#.k8s.io.api.core.v1.ObjectReference\x12\x14\n\x0cnotifierName\x18\x04 \x01(\t\x12\x14\n\x0cparticipants\x18\x05 \x03(\t\x12\x0f\n\x07\x66lagged\x18\x06 \x01(\x08\x12<\n\x08reminder\x18\x07 \x01(\x0b\x32*.k8s.io.apimachinery.pkg.apis.meta.v1.Time\x12\x36\n\ttenantRef\x18\x08 \x01(\x0b\x32#.k8s.io.api.core.v1.ObjectReference\"\xfb\x01\n\rMeetingStatus\x12\r\n\x05phase\x18\x01 \x01(\t\x12\x1a\n\x12observedGeneration\x18\x02 \x01(\x03\x12\r\n\x05notes\x18\x04 \x01(\t\x12\x13\n\x0b\x61\x63tionItems\x18\x05 \x01(\t\x12?\n\x0blastUpdated\x18\x06 \x01(\x0b\x32*.k8s.io.apimachinery.pkg.apis.meta.v1.Time\x12Z\n\nconditions\x18\x07 \x03(\x0b\x32\x46.github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.MeetingCondition\"\xfc\x01\n\nPostMortem\x12\x42\n\x08metadata\x18\x01 \x01(\x0b\x32\x30.k8s.io.apimachinery.pkg.apis.meta.v1.ObjectMeta\x12R\n\x04spec\x18\x02 \x01(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.PostMortemSpec\x12V\n\x06status\x18\x03 \x01(\x0b\x32\x46.github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.PostMortemStatus\"\x9c\x01\n\x13PostMortemCondition\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\x0e\n\x06status\x18\x02 \x01(\t\x12\x46\n\x12lastTransitionTime\x18\x03 \x01(\x0b\x32*.k8s.io.apimachinery.pkg.apis.meta.v1.Time\x12\x0e\n\x06reason\x18\x04 \x01(\t\x12\x0f\n\x07message\x18\x05 \x01(\t\"\xa3\x01\n\x0ePostMortemList\x12@\n\x08metadata\x18\x01 \x01(\x0b\x32..k8s.io.apimachinery.pkg.apis.meta.v1.ListMeta\x12O\n\x05items\x18\x02 \x03(\x0b\x32@.github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.PostMortem\"\xe3\x03\n\x0ePostMortemSpec\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x36\n\tentityRef\x18\x02 \x01(\x0b\x32#.k8s.io.api.core.v1.ObjectReference\x12\x38\n\x0blocationRef\x18\x03 \x01(\x0b\x32#.k8s.io.api.core.v1.ObjectReference\x12\x36\n\thandledBy\x18\x04 \x03(\x0b\x32#.k8s.io.api.core.v1.ObjectReference\x12P\n\x05\x61lert\x18\x05 \x03(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.RaisedAlert\x12U\n\x08timeline\x18\x06 \x03(\x0b\x32\x43.github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.TimeLineEvent\x12\x11\n\trootCause\x18\x07 \x01(\t\x12\x0f\n\x07summary\x18\x08 \x01(\t\x12\r\n\x05owner\x18\t \x01(\t\x12\x36\n\ttenantRef\x18\n \x01(\x0b\x32#.k8s.io.api.core.v1.ObjectReference\"\xce\x01\n\x10PostMortemStatus\x12\x1a\n\x12observedGeneration\x18\x01 \x01(\x03\x12?\n\x0blastUpdated\x18\x02 \x01(\x0b\x32*.k8s.io.apimachinery.pkg.apis.meta.v1.Time\x12]\n\nconditions\x18\x03 \x03(\x0b\x32I.github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.PostMortemCondition\"S\n\x0bRaisedAlert\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x36\n\x02\x61t\x18\x02 \x01(\x0b\x32*.k8s.io.apimachinery.pkg.apis.meta.v1.Time\"\xf0\x01\n\x06Review\x12\x42\n\x08metadata\x18\x01 \x01(\x0b\x32\x30.k8s.io.apimachinery.pkg.apis.meta.v1.ObjectMeta\x12N\n\x04spec\x18\x02 \x01(\x0b\x32@.github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.ReviewSpec\x12R\n\x06status\x18\x03 \x01(\x0b\x32\x42.github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.ReviewStatus\"\x98\x01\n\x0fReviewCondition\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\x0e\n\x06status\x18\x02 \x01(\t\x12\x46\n\x12lastTransitionTime\x18\x03 \x01(\x0b\x32*.k8s.io.apimachinery.pkg.apis.meta.v1.Time\x12\x0e\n\x06reason\x18\x04 \x01(\t\x12\x0f\n\x07message\x18\x05 \x01(\t\"\x9b\x01\n\nReviewList\x12@\n\x08metadata\x18\x01 \x01(\x0b\x32..k8s.io.apimachinery.pkg.apis.meta.v1.ListMeta\x12K\n\x05items\x18\x02 \x03(\x0b\x32<.github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.Review\"\xf2\x01\n\nReviewSpec\x12\x36\n\tentityRef\x18\x01 \x01(\x0b\x32#.k8s.io.api.core.v1.ObjectReference\x12O\n\x08messages\x18\x02 \x03(\x0b\x32=.github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.Comment\x12\r\n\x05owner\x18\x03 \x01(\t\x12\x14\n\x0cnotifierName\x18\x04 \x01(\t\x12\x36\n\ttenantRef\x18\x05 \x01(\x0b\x32#.k8s.io.api.core.v1.ObjectReference\"\xc6\x01\n\x0cReviewStatus\x12?\n\x0blastUpdated\x18\x01 \x01(\x0b\x32*.k8s.io.apimachinery.pkg.apis.meta.v1.Time\x12\x1a\n\x12observedGeneration\x18\x02 \x01(\x03\x12Y\n\nconditions\x18\x03 \x03(\x0b\x32\x45.github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.ReviewCondition\"\xf3\x01\n\x07RunBook\x12\x42\n\x08metadata\x18\x01 \x01(\x0b\x32\x30.k8s.io.apimachinery.pkg.apis.meta.v1.ObjectMeta\x12O\n\x04spec\x18\x02 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.RunBookSpec\x12S\n\x06status\x18\x03 \x01(\x0b\x32\x43.github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.RunBookStatus\"\xdd\x01\n\x10RunBookCondition\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\x0e\n\x06status\x18\x02 \x01(\t\x12\x42\n\x0elastUpdateTime\x18\x03 \x01(\x0b\x32*.k8s.io.apimachinery.pkg.apis.meta.v1.Time\x12\x46\n\x12lastTransitionTime\x18\x04 \x01(\x0b\x32*.k8s.io.apimachinery.pkg.apis.meta.v1.Time\x12\x0e\n\x06reason\x18\x05 \x01(\t\x12\x0f\n\x07message\x18\x06 \x01(\t\"\x9d\x01\n\x0bRunBookList\x12@\n\x08metadata\x18\x01 \x01(\x0b\x32..k8s.io.apimachinery.pkg.apis.meta.v1.ListMeta\x12L\n\x05items\x18\x02 \x03(\x0b\x32=.github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.RunBook\"\xb1\x02\n\x0bRunBookSpec\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x36\n\tentityRef\x18\x02 \x01(\x0b\x32#.k8s.io.api.core.v1.ObjectReference\x12\x36\n\tauthorRef\x18\x03 \x01(\x0b\x32#.k8s.io.api.core.v1.ObjectReference\x12V\n\tchecklist\x18\x04 \x03(\x0b\x32\x43.github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.CheckListItem\x12\r\n\x05owner\x18\x05 \x01(\t\x12\x36\n\ttenantRef\x18\x06 \x01(\x0b\x32#.k8s.io.api.core.v1.ObjectReference\"\xc8\x01\n\rRunBookStatus\x12\x1a\n\x12observedGeneration\x18\x01 \x01(\x03\x12?\n\x0blastUpdated\x18\x02 \x01(\x0b\x32*.k8s.io.apimachinery.pkg.apis.meta.v1.Time\x12Z\n\nconditions\x18\x03 \x03(\x0b\x32\x46.github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.RunBookCondition\"X\n\rTimeLineEvent\x12\x0f\n\x07\x63ontent\x18\x01 \x01(\t\x12\x36\n\x02\x61t\x18\x02 \x01(\x0b\x32*.k8s.io.apimachinery.pkg.apis.meta.v1.Time\"\xea\x01\n\x04Todo\x12\x42\n\x08metadata\x18\x01 \x01(\x0b\x32\x30.k8s.io.apimachinery.pkg.apis.meta.v1.ObjectMeta\x12L\n\x04spec\x18\x02 \x01(\x0b\x32>.github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.TodoSpec\x12P\n\x06status\x18\x03 \x01(\x0b\x32@.github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.TodoStatus\"\x96\x01\n\rTodoCondition\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\x0e\n\x06status\x18\x02 \x01(\t\x12\x46\n\x12lastTransitionTime\x18\x03 \x01(\x0b\x32*.k8s.io.apimachinery.pkg.apis.meta.v1.Time\x12\x0e\n\x06reason\x18\x04 \x01(\t\x12\x0f\n\x07message\x18\x05 \x01(\t\"\x97\x01\n\x08TodoList\x12@\n\x08metadata\x18\x01 \x01(\x0b\x32..k8s.io.apimachinery.pkg.apis.meta.v1.ListMeta\x12I\n\x05items\x18\x02 \x03(\x0b\x32:.github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.Todo\"\xe7\x02\n\x08TodoSpec\x12\x0c\n\x04task\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x36\n\tentityRef\x18\x03 \x01(\x0b\x32#.k8s.io.api.core.v1.ObjectReference\x12\x14\n\x0cnotifierName\x18\x04 \x01(\t\x12\x12\n\nassignedTo\x18\x05 \x01(\t\x12\x0f\n\x07\x66lagged\x18\x06 \x01(\x08\x12<\n\x08reminder\x18\x07 \x01(\x0b\x32*.k8s.io.apimachinery.pkg.apis.meta.v1.Time\x12;\n\x07\x64ueDate\x18\x08 \x01(\x0b\x32*.k8s.io.apimachinery.pkg.apis.meta.v1.Time\x12\x12\n\nparentTask\x18\t \x01(\t\x12\x36\n\ttenantRef\x18\n \x01(\x0b\x32#.k8s.io.api.core.v1.ObjectReference\"\xd1\x01\n\nTodoStatus\x12\r\n\x05phase\x18\x01 \x01(\t\x12\x1a\n\x12observedGeneration\x18\x02 \x01(\x03\x12?\n\x0blastUpdated\x18\x06 \x01(\x0b\x32*.k8s.io.apimachinery.pkg.apis.meta.v1.Time\x12W\n\nconditions\x18\x03 \x03(\x0b\x32\x43.github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.TodoConditionB6Z4github.com/metaprov/modelaapi/pkg/apis/team/v1alpha1')



_CHECKLISTITEM = DESCRIPTOR.message_types_by_name['CheckListItem']
_COMMENT = DESCRIPTOR.message_types_by_name['Comment']
_MEETING = DESCRIPTOR.message_types_by_name['Meeting']
_MEETINGCONDITION = DESCRIPTOR.message_types_by_name['MeetingCondition']
_MEETINGLIST = DESCRIPTOR.message_types_by_name['MeetingList']
_MEETINGSPEC = DESCRIPTOR.message_types_by_name['MeetingSpec']
_MEETINGSTATUS = DESCRIPTOR.message_types_by_name['MeetingStatus']
_POSTMORTEM = DESCRIPTOR.message_types_by_name['PostMortem']
_POSTMORTEMCONDITION = DESCRIPTOR.message_types_by_name['PostMortemCondition']
_POSTMORTEMLIST = DESCRIPTOR.message_types_by_name['PostMortemList']
_POSTMORTEMSPEC = DESCRIPTOR.message_types_by_name['PostMortemSpec']
_POSTMORTEMSTATUS = DESCRIPTOR.message_types_by_name['PostMortemStatus']
_RAISEDALERT = DESCRIPTOR.message_types_by_name['RaisedAlert']
_REVIEW = DESCRIPTOR.message_types_by_name['Review']
_REVIEWCONDITION = DESCRIPTOR.message_types_by_name['ReviewCondition']
_REVIEWLIST = DESCRIPTOR.message_types_by_name['ReviewList']
_REVIEWSPEC = DESCRIPTOR.message_types_by_name['ReviewSpec']
_REVIEWSTATUS = DESCRIPTOR.message_types_by_name['ReviewStatus']
_RUNBOOK = DESCRIPTOR.message_types_by_name['RunBook']
_RUNBOOKCONDITION = DESCRIPTOR.message_types_by_name['RunBookCondition']
_RUNBOOKLIST = DESCRIPTOR.message_types_by_name['RunBookList']
_RUNBOOKSPEC = DESCRIPTOR.message_types_by_name['RunBookSpec']
_RUNBOOKSTATUS = DESCRIPTOR.message_types_by_name['RunBookStatus']
_TIMELINEEVENT = DESCRIPTOR.message_types_by_name['TimeLineEvent']
_TODO = DESCRIPTOR.message_types_by_name['Todo']
_TODOCONDITION = DESCRIPTOR.message_types_by_name['TodoCondition']
_TODOLIST = DESCRIPTOR.message_types_by_name['TodoList']
_TODOSPEC = DESCRIPTOR.message_types_by_name['TodoSpec']
_TODOSTATUS = DESCRIPTOR.message_types_by_name['TodoStatus']
CheckListItem = _reflection.GeneratedProtocolMessageType('CheckListItem', (_message.Message,), {
  'DESCRIPTOR' : _CHECKLISTITEM,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.CheckListItem)
  })
_sym_db.RegisterMessage(CheckListItem)

Comment = _reflection.GeneratedProtocolMessageType('Comment', (_message.Message,), {
  'DESCRIPTOR' : _COMMENT,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.Comment)
  })
_sym_db.RegisterMessage(Comment)

Meeting = _reflection.GeneratedProtocolMessageType('Meeting', (_message.Message,), {
  'DESCRIPTOR' : _MEETING,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.Meeting)
  })
_sym_db.RegisterMessage(Meeting)

MeetingCondition = _reflection.GeneratedProtocolMessageType('MeetingCondition', (_message.Message,), {
  'DESCRIPTOR' : _MEETINGCONDITION,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.MeetingCondition)
  })
_sym_db.RegisterMessage(MeetingCondition)

MeetingList = _reflection.GeneratedProtocolMessageType('MeetingList', (_message.Message,), {
  'DESCRIPTOR' : _MEETINGLIST,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.MeetingList)
  })
_sym_db.RegisterMessage(MeetingList)

MeetingSpec = _reflection.GeneratedProtocolMessageType('MeetingSpec', (_message.Message,), {
  'DESCRIPTOR' : _MEETINGSPEC,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.MeetingSpec)
  })
_sym_db.RegisterMessage(MeetingSpec)

MeetingStatus = _reflection.GeneratedProtocolMessageType('MeetingStatus', (_message.Message,), {
  'DESCRIPTOR' : _MEETINGSTATUS,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.MeetingStatus)
  })
_sym_db.RegisterMessage(MeetingStatus)

PostMortem = _reflection.GeneratedProtocolMessageType('PostMortem', (_message.Message,), {
  'DESCRIPTOR' : _POSTMORTEM,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.PostMortem)
  })
_sym_db.RegisterMessage(PostMortem)

PostMortemCondition = _reflection.GeneratedProtocolMessageType('PostMortemCondition', (_message.Message,), {
  'DESCRIPTOR' : _POSTMORTEMCONDITION,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.PostMortemCondition)
  })
_sym_db.RegisterMessage(PostMortemCondition)

PostMortemList = _reflection.GeneratedProtocolMessageType('PostMortemList', (_message.Message,), {
  'DESCRIPTOR' : _POSTMORTEMLIST,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.PostMortemList)
  })
_sym_db.RegisterMessage(PostMortemList)

PostMortemSpec = _reflection.GeneratedProtocolMessageType('PostMortemSpec', (_message.Message,), {
  'DESCRIPTOR' : _POSTMORTEMSPEC,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.PostMortemSpec)
  })
_sym_db.RegisterMessage(PostMortemSpec)

PostMortemStatus = _reflection.GeneratedProtocolMessageType('PostMortemStatus', (_message.Message,), {
  'DESCRIPTOR' : _POSTMORTEMSTATUS,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.PostMortemStatus)
  })
_sym_db.RegisterMessage(PostMortemStatus)

RaisedAlert = _reflection.GeneratedProtocolMessageType('RaisedAlert', (_message.Message,), {
  'DESCRIPTOR' : _RAISEDALERT,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.RaisedAlert)
  })
_sym_db.RegisterMessage(RaisedAlert)

Review = _reflection.GeneratedProtocolMessageType('Review', (_message.Message,), {
  'DESCRIPTOR' : _REVIEW,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.Review)
  })
_sym_db.RegisterMessage(Review)

ReviewCondition = _reflection.GeneratedProtocolMessageType('ReviewCondition', (_message.Message,), {
  'DESCRIPTOR' : _REVIEWCONDITION,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.ReviewCondition)
  })
_sym_db.RegisterMessage(ReviewCondition)

ReviewList = _reflection.GeneratedProtocolMessageType('ReviewList', (_message.Message,), {
  'DESCRIPTOR' : _REVIEWLIST,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.ReviewList)
  })
_sym_db.RegisterMessage(ReviewList)

ReviewSpec = _reflection.GeneratedProtocolMessageType('ReviewSpec', (_message.Message,), {
  'DESCRIPTOR' : _REVIEWSPEC,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.ReviewSpec)
  })
_sym_db.RegisterMessage(ReviewSpec)

ReviewStatus = _reflection.GeneratedProtocolMessageType('ReviewStatus', (_message.Message,), {
  'DESCRIPTOR' : _REVIEWSTATUS,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.ReviewStatus)
  })
_sym_db.RegisterMessage(ReviewStatus)

RunBook = _reflection.GeneratedProtocolMessageType('RunBook', (_message.Message,), {
  'DESCRIPTOR' : _RUNBOOK,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.RunBook)
  })
_sym_db.RegisterMessage(RunBook)

RunBookCondition = _reflection.GeneratedProtocolMessageType('RunBookCondition', (_message.Message,), {
  'DESCRIPTOR' : _RUNBOOKCONDITION,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.RunBookCondition)
  })
_sym_db.RegisterMessage(RunBookCondition)

RunBookList = _reflection.GeneratedProtocolMessageType('RunBookList', (_message.Message,), {
  'DESCRIPTOR' : _RUNBOOKLIST,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.RunBookList)
  })
_sym_db.RegisterMessage(RunBookList)

RunBookSpec = _reflection.GeneratedProtocolMessageType('RunBookSpec', (_message.Message,), {
  'DESCRIPTOR' : _RUNBOOKSPEC,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.RunBookSpec)
  })
_sym_db.RegisterMessage(RunBookSpec)

RunBookStatus = _reflection.GeneratedProtocolMessageType('RunBookStatus', (_message.Message,), {
  'DESCRIPTOR' : _RUNBOOKSTATUS,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.RunBookStatus)
  })
_sym_db.RegisterMessage(RunBookStatus)

TimeLineEvent = _reflection.GeneratedProtocolMessageType('TimeLineEvent', (_message.Message,), {
  'DESCRIPTOR' : _TIMELINEEVENT,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.TimeLineEvent)
  })
_sym_db.RegisterMessage(TimeLineEvent)

Todo = _reflection.GeneratedProtocolMessageType('Todo', (_message.Message,), {
  'DESCRIPTOR' : _TODO,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.Todo)
  })
_sym_db.RegisterMessage(Todo)

TodoCondition = _reflection.GeneratedProtocolMessageType('TodoCondition', (_message.Message,), {
  'DESCRIPTOR' : _TODOCONDITION,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.TodoCondition)
  })
_sym_db.RegisterMessage(TodoCondition)

TodoList = _reflection.GeneratedProtocolMessageType('TodoList', (_message.Message,), {
  'DESCRIPTOR' : _TODOLIST,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.TodoList)
  })
_sym_db.RegisterMessage(TodoList)

TodoSpec = _reflection.GeneratedProtocolMessageType('TodoSpec', (_message.Message,), {
  'DESCRIPTOR' : _TODOSPEC,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.TodoSpec)
  })
_sym_db.RegisterMessage(TodoSpec)

TodoStatus = _reflection.GeneratedProtocolMessageType('TodoStatus', (_message.Message,), {
  'DESCRIPTOR' : _TODOSTATUS,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.TodoStatus)
  })
_sym_db.RegisterMessage(TodoStatus)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z4github.com/metaprov/modelaapi/pkg/apis/team/v1alpha1'
  _CHECKLISTITEM._serialized_start=321
  _CHECKLISTITEM._serialized_end=431
  _COMMENT._serialized_start=434
  _COMMENT._serialized_end=708
  _MEETING._serialized_start=711
  _MEETING._serialized_end=954
  _MEETINGCONDITION._serialized_start=957
  _MEETINGCONDITION._serialized_end=1110
  _MEETINGLIST._serialized_start=1113
  _MEETINGLIST._serialized_end=1270
  _MEETINGSPEC._serialized_start=1273
  _MEETINGSPEC._serialized_end=1558
  _MEETINGSTATUS._serialized_start=1561
  _MEETINGSTATUS._serialized_end=1812
  _POSTMORTEM._serialized_start=1815
  _POSTMORTEM._serialized_end=2067
  _POSTMORTEMCONDITION._serialized_start=2070
  _POSTMORTEMCONDITION._serialized_end=2226
  _POSTMORTEMLIST._serialized_start=2229
  _POSTMORTEMLIST._serialized_end=2392
  _POSTMORTEMSPEC._serialized_start=2395
  _POSTMORTEMSPEC._serialized_end=2878
  _POSTMORTEMSTATUS._serialized_start=2881
  _POSTMORTEMSTATUS._serialized_end=3087
  _RAISEDALERT._serialized_start=3089
  _RAISEDALERT._serialized_end=3172
  _REVIEW._serialized_start=3175
  _REVIEW._serialized_end=3415
  _REVIEWCONDITION._serialized_start=3418
  _REVIEWCONDITION._serialized_end=3570
  _REVIEWLIST._serialized_start=3573
  _REVIEWLIST._serialized_end=3728
  _REVIEWSPEC._serialized_start=3731
  _REVIEWSPEC._serialized_end=3973
  _REVIEWSTATUS._serialized_start=3976
  _REVIEWSTATUS._serialized_end=4174
  _RUNBOOK._serialized_start=4177
  _RUNBOOK._serialized_end=4420
  _RUNBOOKCONDITION._serialized_start=4423
  _RUNBOOKCONDITION._serialized_end=4644
  _RUNBOOKLIST._serialized_start=4647
  _RUNBOOKLIST._serialized_end=4804
  _RUNBOOKSPEC._serialized_start=4807
  _RUNBOOKSPEC._serialized_end=5112
  _RUNBOOKSTATUS._serialized_start=5115
  _RUNBOOKSTATUS._serialized_end=5315
  _TIMELINEEVENT._serialized_start=5317
  _TIMELINEEVENT._serialized_end=5405
  _TODO._serialized_start=5408
  _TODO._serialized_end=5642
  _TODOCONDITION._serialized_start=5645
  _TODOCONDITION._serialized_end=5795
  _TODOLIST._serialized_start=5798
  _TODOLIST._serialized_end=5949
  _TODOSPEC._serialized_start=5952
  _TODOSPEC._serialized_end=6311
  _TODOSTATUS._serialized_start=6314
  _TODOSTATUS._serialized_end=6523
# @@protoc_insertion_point(module_scope)
