# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: k8s.io/apimachinery/pkg/runtime/generated.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n/k8s.io/apimachinery/pkg/runtime/generated.proto\x12\x1fk8s.io.apimachinery.pkg.runtime\"\x1b\n\x0cRawExtension\x12\x0b\n\x03raw\x18\x01 \x01(\x0c\",\n\x08TypeMeta\x12\x12\n\napiVersion\x18\x01 \x01(\t\x12\x0c\n\x04kind\x18\x02 \x01(\t\"\x81\x01\n\x07Unknown\x12;\n\x08typeMeta\x18\x01 \x01(\x0b\x32).k8s.io.apimachinery.pkg.runtime.TypeMeta\x12\x0b\n\x03raw\x18\x02 \x01(\x0c\x12\x17\n\x0f\x63ontentEncoding\x18\x03 \x01(\t\x12\x13\n\x0b\x63ontentType\x18\x04 \x01(\tB!Z\x1fk8s.io/apimachinery/pkg/runtime')



_RAWEXTENSION = DESCRIPTOR.message_types_by_name['RawExtension']
_TYPEMETA = DESCRIPTOR.message_types_by_name['TypeMeta']
_UNKNOWN = DESCRIPTOR.message_types_by_name['Unknown']
RawExtension = _reflection.GeneratedProtocolMessageType('RawExtension', (_message.Message,), {
  'DESCRIPTOR' : _RAWEXTENSION,
  '__module__' : 'k8s.io.apimachinery.pkg.runtime.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.apimachinery.pkg.runtime.RawExtension)
  })
_sym_db.RegisterMessage(RawExtension)

TypeMeta = _reflection.GeneratedProtocolMessageType('TypeMeta', (_message.Message,), {
  'DESCRIPTOR' : _TYPEMETA,
  '__module__' : 'k8s.io.apimachinery.pkg.runtime.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.apimachinery.pkg.runtime.TypeMeta)
  })
_sym_db.RegisterMessage(TypeMeta)

Unknown = _reflection.GeneratedProtocolMessageType('Unknown', (_message.Message,), {
  'DESCRIPTOR' : _UNKNOWN,
  '__module__' : 'k8s.io.apimachinery.pkg.runtime.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.apimachinery.pkg.runtime.Unknown)
  })
_sym_db.RegisterMessage(Unknown)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z\037k8s.io/apimachinery/pkg/runtime'
  _RAWEXTENSION._serialized_start=84
  _RAWEXTENSION._serialized_end=111
  _TYPEMETA._serialized_start=113
  _TYPEMETA._serialized_end=157
  _UNKNOWN._serialized_start=160
  _UNKNOWN._serialized_end=289
# @@protoc_insertion_point(module_scope)
