# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from github.com.metaprov.modelaapi.services.curtain.v1 import curtain_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_curtain_dot_v1_dot_curtain__pb2


class CurtainServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.ListCurtains = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.curtain.v1.CurtainService/ListCurtains',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_curtain_dot_v1_dot_curtain__pb2.ListCurtainsRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_curtain_dot_v1_dot_curtain__pb2.ListCurtainsResponse.FromString,
                )
        self.CreateCurtain = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.curtain.v1.CurtainService/CreateCurtain',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_curtain_dot_v1_dot_curtain__pb2.CreateCurtainRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_curtain_dot_v1_dot_curtain__pb2.CreateCurtainResponse.FromString,
                )
        self.GetCurtain = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.curtain.v1.CurtainService/GetCurtain',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_curtain_dot_v1_dot_curtain__pb2.GetCurtainRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_curtain_dot_v1_dot_curtain__pb2.GetCurtainResponse.FromString,
                )
        self.UpdateCurtain = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.curtain.v1.CurtainService/UpdateCurtain',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_curtain_dot_v1_dot_curtain__pb2.UpdateCurtainRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_curtain_dot_v1_dot_curtain__pb2.UpdateCurtainResponse.FromString,
                )
        self.DeleteCurtain = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.curtain.v1.CurtainService/DeleteCurtain',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_curtain_dot_v1_dot_curtain__pb2.DeleteCurtainRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_curtain_dot_v1_dot_curtain__pb2.DeleteCurtainResponse.FromString,
                )


class CurtainServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def ListCurtains(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateCurtain(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetCurtain(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateCurtain(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteCurtain(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_CurtainServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'ListCurtains': grpc.unary_unary_rpc_method_handler(
                    servicer.ListCurtains,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_curtain_dot_v1_dot_curtain__pb2.ListCurtainsRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_curtain_dot_v1_dot_curtain__pb2.ListCurtainsResponse.SerializeToString,
            ),
            'CreateCurtain': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateCurtain,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_curtain_dot_v1_dot_curtain__pb2.CreateCurtainRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_curtain_dot_v1_dot_curtain__pb2.CreateCurtainResponse.SerializeToString,
            ),
            'GetCurtain': grpc.unary_unary_rpc_method_handler(
                    servicer.GetCurtain,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_curtain_dot_v1_dot_curtain__pb2.GetCurtainRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_curtain_dot_v1_dot_curtain__pb2.GetCurtainResponse.SerializeToString,
            ),
            'UpdateCurtain': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateCurtain,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_curtain_dot_v1_dot_curtain__pb2.UpdateCurtainRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_curtain_dot_v1_dot_curtain__pb2.UpdateCurtainResponse.SerializeToString,
            ),
            'DeleteCurtain': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteCurtain,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_curtain_dot_v1_dot_curtain__pb2.DeleteCurtainRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_curtain_dot_v1_dot_curtain__pb2.DeleteCurtainResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'github.com.metaprov.modelaapi.services.curtain.v1.CurtainService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class CurtainService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def ListCurtains(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.curtain.v1.CurtainService/ListCurtains',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_curtain_dot_v1_dot_curtain__pb2.ListCurtainsRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_curtain_dot_v1_dot_curtain__pb2.ListCurtainsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateCurtain(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.curtain.v1.CurtainService/CreateCurtain',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_curtain_dot_v1_dot_curtain__pb2.CreateCurtainRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_curtain_dot_v1_dot_curtain__pb2.CreateCurtainResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetCurtain(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.curtain.v1.CurtainService/GetCurtain',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_curtain_dot_v1_dot_curtain__pb2.GetCurtainRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_curtain_dot_v1_dot_curtain__pb2.GetCurtainResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateCurtain(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.curtain.v1.CurtainService/UpdateCurtain',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_curtain_dot_v1_dot_curtain__pb2.UpdateCurtainRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_curtain_dot_v1_dot_curtain__pb2.UpdateCurtainResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteCurtain(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.curtain.v1.CurtainService/DeleteCurtain',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_curtain_dot_v1_dot_curtain__pb2.DeleteCurtainRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_curtain_dot_v1_dot_curtain__pb2.DeleteCurtainResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
