# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: github.com/metaprov/modelaapi/services/todo/v1/todo.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1 import generated_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_team_dot_v1alpha1_dot_generated__pb2
from github.com.metaprov.modelaapi.services.common.v1 import common_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_common_dot_v1_dot_common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n9github.com/metaprov/modelaapi/services/todo/v1/todo.proto\x12.github.com.metaprov.modelaapi.services.todo.v1\x1a google/protobuf/field_mask.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x44github.com/metaprov/modelaapi/pkg/apis/team/v1alpha1/generated.proto\x1a=github.com/metaprov/modelaapi/services/common/v1/common.proto\"\xb2\x01\n\x10ListTodosRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\\\n\x06labels\x18\x02 \x03(\x0b\x32L.github.com.metaprov.modelaapi.services.todo.v1.ListTodosRequest.LabelsEntry\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"{\n\x11ListTodosResponse\x12M\n\x05todos\x18\x01 \x01(\x0b\x32>.github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.TodoList\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"o\n\x11\x43reateTodoRequest\x12H\n\x04todo\x18\x01 \x01(\x0b\x32:.github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.Todo\x12\x10\n\x08password\x18\x02 \x01(\t\"\x14\n\x12\x43reateTodoResponse\"\x8d\x01\n\x11UpdateTodoRequest\x12H\n\x04todo\x18\x01 \x01(\x0b\x32:.github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.Todo\x12.\n\nfield_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\"\x14\n\x12UpdateTodoResponse\"1\n\x0eGetTodoRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"i\n\x0fGetTodoResponse\x12H\n\x04todo\x18\x01 \x01(\x0b\x32:.github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.Todo\x12\x0c\n\x04yaml\x18\x02 \x01(\t\"4\n\x11\x44\x65leteTodoRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x14\n\x12\x44\x65leteTodoResponse2\xb5\x07\n\x0bTodoService\x12\xaf\x01\n\tListTodos\x12@.github.com.metaprov.modelaapi.services.todo.v1.ListTodosRequest\x1a\x41.github.com.metaprov.modelaapi.services.todo.v1.ListTodosResponse\"\x1d\x82\xd3\xe4\x93\x02\x17\x12\x15/v1/todos/{namespace}\x12\xa9\x01\n\nCreateTodo\x12\x41.github.com.metaprov.modelaapi.services.todo.v1.CreateTodoRequest\x1a\x42.github.com.metaprov.modelaapi.services.todo.v1.CreateTodoResponse\"\x14\x82\xd3\xe4\x93\x02\x0e\"\t/v1/todos:\x01*\x12\xb0\x01\n\x07GetTodo\x12>.github.com.metaprov.modelaapi.services.todo.v1.GetTodoRequest\x1a?.github.com.metaprov.modelaapi.services.todo.v1.GetTodoResponse\"$\x82\xd3\xe4\x93\x02\x1e\x12\x1c/v1/todos/{namespace}/{name}\x12\xd8\x01\n\nUpdateTodo\x12\x41.github.com.metaprov.modelaapi.services.todo.v1.UpdateTodoRequest\x1a\x42.github.com.metaprov.modelaapi.services.todo.v1.UpdateTodoResponse\"C\x82\xd3\xe4\x93\x02=\x1a\x38/v1/todos/{todo.metadata.namespace}/{todo.metadata.name}:\x01*\x12\xb9\x01\n\nDeleteTodo\x12\x41.github.com.metaprov.modelaapi.services.todo.v1.DeleteTodoRequest\x1a\x42.github.com.metaprov.modelaapi.services.todo.v1.DeleteTodoResponse\"$\x82\xd3\xe4\x93\x02\x1e*\x1c/v1/todos/{namespace}/{name}B0Z.github.com/metaprov/modelaapi/services/todo/v1b\x06proto3')



_LISTTODOSREQUEST = DESCRIPTOR.message_types_by_name['ListTodosRequest']
_LISTTODOSREQUEST_LABELSENTRY = _LISTTODOSREQUEST.nested_types_by_name['LabelsEntry']
_LISTTODOSRESPONSE = DESCRIPTOR.message_types_by_name['ListTodosResponse']
_CREATETODOREQUEST = DESCRIPTOR.message_types_by_name['CreateTodoRequest']
_CREATETODORESPONSE = DESCRIPTOR.message_types_by_name['CreateTodoResponse']
_UPDATETODOREQUEST = DESCRIPTOR.message_types_by_name['UpdateTodoRequest']
_UPDATETODORESPONSE = DESCRIPTOR.message_types_by_name['UpdateTodoResponse']
_GETTODOREQUEST = DESCRIPTOR.message_types_by_name['GetTodoRequest']
_GETTODORESPONSE = DESCRIPTOR.message_types_by_name['GetTodoResponse']
_DELETETODOREQUEST = DESCRIPTOR.message_types_by_name['DeleteTodoRequest']
_DELETETODORESPONSE = DESCRIPTOR.message_types_by_name['DeleteTodoResponse']
ListTodosRequest = _reflection.GeneratedProtocolMessageType('ListTodosRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _LISTTODOSREQUEST_LABELSENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.todo.v1.todo_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.todo.v1.ListTodosRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _LISTTODOSREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.todo.v1.todo_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.todo.v1.ListTodosRequest)
  })
_sym_db.RegisterMessage(ListTodosRequest)
_sym_db.RegisterMessage(ListTodosRequest.LabelsEntry)

ListTodosResponse = _reflection.GeneratedProtocolMessageType('ListTodosResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTTODOSRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.todo.v1.todo_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.todo.v1.ListTodosResponse)
  })
_sym_db.RegisterMessage(ListTodosResponse)

CreateTodoRequest = _reflection.GeneratedProtocolMessageType('CreateTodoRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATETODOREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.todo.v1.todo_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.todo.v1.CreateTodoRequest)
  })
_sym_db.RegisterMessage(CreateTodoRequest)

CreateTodoResponse = _reflection.GeneratedProtocolMessageType('CreateTodoResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATETODORESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.todo.v1.todo_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.todo.v1.CreateTodoResponse)
  })
_sym_db.RegisterMessage(CreateTodoResponse)

UpdateTodoRequest = _reflection.GeneratedProtocolMessageType('UpdateTodoRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATETODOREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.todo.v1.todo_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.todo.v1.UpdateTodoRequest)
  })
_sym_db.RegisterMessage(UpdateTodoRequest)

UpdateTodoResponse = _reflection.GeneratedProtocolMessageType('UpdateTodoResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATETODORESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.todo.v1.todo_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.todo.v1.UpdateTodoResponse)
  })
_sym_db.RegisterMessage(UpdateTodoResponse)

GetTodoRequest = _reflection.GeneratedProtocolMessageType('GetTodoRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETTODOREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.todo.v1.todo_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.todo.v1.GetTodoRequest)
  })
_sym_db.RegisterMessage(GetTodoRequest)

GetTodoResponse = _reflection.GeneratedProtocolMessageType('GetTodoResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETTODORESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.todo.v1.todo_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.todo.v1.GetTodoResponse)
  })
_sym_db.RegisterMessage(GetTodoResponse)

DeleteTodoRequest = _reflection.GeneratedProtocolMessageType('DeleteTodoRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETETODOREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.todo.v1.todo_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.todo.v1.DeleteTodoRequest)
  })
_sym_db.RegisterMessage(DeleteTodoRequest)

DeleteTodoResponse = _reflection.GeneratedProtocolMessageType('DeleteTodoResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETETODORESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.todo.v1.todo_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.todo.v1.DeleteTodoResponse)
  })
_sym_db.RegisterMessage(DeleteTodoResponse)

_TODOSERVICE = DESCRIPTOR.services_by_name['TodoService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z.github.com/metaprov/modelaapi/services/todo/v1'
  _LISTTODOSREQUEST_LABELSENTRY._options = None
  _LISTTODOSREQUEST_LABELSENTRY._serialized_options = b'8\001'
  _TODOSERVICE.methods_by_name['ListTodos']._options = None
  _TODOSERVICE.methods_by_name['ListTodos']._serialized_options = b'\202\323\344\223\002\027\022\025/v1/todos/{namespace}'
  _TODOSERVICE.methods_by_name['CreateTodo']._options = None
  _TODOSERVICE.methods_by_name['CreateTodo']._serialized_options = b'\202\323\344\223\002\016\"\t/v1/todos:\001*'
  _TODOSERVICE.methods_by_name['GetTodo']._options = None
  _TODOSERVICE.methods_by_name['GetTodo']._serialized_options = b'\202\323\344\223\002\036\022\034/v1/todos/{namespace}/{name}'
  _TODOSERVICE.methods_by_name['UpdateTodo']._options = None
  _TODOSERVICE.methods_by_name['UpdateTodo']._serialized_options = b'\202\323\344\223\002=\0328/v1/todos/{todo.metadata.namespace}/{todo.metadata.name}:\001*'
  _TODOSERVICE.methods_by_name['DeleteTodo']._options = None
  _TODOSERVICE.methods_by_name['DeleteTodo']._serialized_options = b'\202\323\344\223\002\036*\034/v1/todos/{namespace}/{name}'
  _LISTTODOSREQUEST._serialized_start=307
  _LISTTODOSREQUEST._serialized_end=485
  _LISTTODOSREQUEST_LABELSENTRY._serialized_start=440
  _LISTTODOSREQUEST_LABELSENTRY._serialized_end=485
  _LISTTODOSRESPONSE._serialized_start=487
  _LISTTODOSRESPONSE._serialized_end=610
  _CREATETODOREQUEST._serialized_start=612
  _CREATETODOREQUEST._serialized_end=723
  _CREATETODORESPONSE._serialized_start=725
  _CREATETODORESPONSE._serialized_end=745
  _UPDATETODOREQUEST._serialized_start=748
  _UPDATETODOREQUEST._serialized_end=889
  _UPDATETODORESPONSE._serialized_start=891
  _UPDATETODORESPONSE._serialized_end=911
  _GETTODOREQUEST._serialized_start=913
  _GETTODOREQUEST._serialized_end=962
  _GETTODORESPONSE._serialized_start=964
  _GETTODORESPONSE._serialized_end=1069
  _DELETETODOREQUEST._serialized_start=1071
  _DELETETODOREQUEST._serialized_end=1123
  _DELETETODORESPONSE._serialized_start=1125
  _DELETETODORESPONSE._serialized_end=1145
  _TODOSERVICE._serialized_start=1148
  _TODOSERVICE._serialized_end=2097
# @@protoc_insertion_point(module_scope)
