# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: github.com/metaprov/modelaapi/services/datapipelinerun/v1/datapipelinerun.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1 import generated_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nOgithub.com/metaprov/modelaapi/services/datapipelinerun/v1/datapipelinerun.proto\x12\x39github.com.metaprov.modelaapi.services.datapipelinerun.v1\x1a google/protobuf/field_mask.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x44github.com/metaprov/modelaapi/pkg/apis/data/v1alpha1/generated.proto\"\x8a\x02\n\x1aListDataPipelineRunRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12q\n\x06labels\x18\x02 \x03(\x0b\x32\x61.github.com.metaprov.modelaapi.services.datapipelinerun.v1.ListDataPipelineRunRequest.LabelsEntry\x12\x11\n\tpage_size\x18\x03 \x01(\x05\x12\x12\n\npage_token\x18\x04 \x01(\t\x12\x10\n\x08order_by\x18\x05 \x01(\t\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x9b\x01\n\x1bListDataPipelineRunResponse\x12\x63\n\x10\x64\x61tapipelineruns\x18\x01 \x01(\x0b\x32I.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataPipelineRunList\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"~\n\x1c\x43reateDataPipelineRunRequest\x12^\n\x0f\x64\x61tapipelinerun\x18\x01 \x01(\x0b\x32\x45.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataPipelineRun\"\x1f\n\x1d\x43reateDataPipelineRunResponse\"\xae\x01\n\x1cUpdateDataPipelineRunRequest\x12^\n\x0f\x64\x61tapipelinerun\x18\x01 \x01(\x0b\x32\x45.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataPipelineRun\x12.\n\nfield_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\"\x1f\n\x1dUpdateDataPipelineRunResponse\"<\n\x19GetDataPipelineRunRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x8a\x01\n\x1aGetDataPipelineRunResponse\x12^\n\x0f\x64\x61tapipelinerun\x18\x01 \x01(\x0b\x32\x45.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataPipelineRun\x12\x0c\n\x04yaml\x18\x02 \x01(\t\"?\n\x1c\x44\x65leteDataPipelineRunRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x1f\n\x1d\x44\x65leteDataPipelineRunResponse\"\x1e\n\x1c\x41\x62ortDataPipelineRunResponse\">\n\x1b\x41\x62ortDataPipelineRunRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x1e\n\x1cPauseDataPipelineRunResponse\">\n\x1bPauseDataPipelineRunRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x1f\n\x1dResumeDataPipelineRunResponse\"?\n\x1cResumeDataPipelineRunRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t2\xa3\x10\n\x16\x44\x61taPipelineRunService\x12\xef\x01\n\x14ListDataPipelineRuns\x12U.github.com.metaprov.modelaapi.services.datapipelinerun.v1.ListDataPipelineRunRequest\x1aV.github.com.metaprov.modelaapi.services.datapipelinerun.v1.ListDataPipelineRunResponse\"(\x82\xd3\xe4\x93\x02\"\x12 /v1/datapipelineruns/{namespace}\x12\xeb\x01\n\x15\x43reateDataPipelineRun\x12W.github.com.metaprov.modelaapi.services.datapipelinerun.v1.CreateDataPipelineRunRequest\x1aX.github.com.metaprov.modelaapi.services.datapipelinerun.v1.CreateDataPipelineRunResponse\"\x1f\x82\xd3\xe4\x93\x02\x19\"\x14/v1/datapipelineruns:\x01*\x12\xf2\x01\n\x12GetDataPipelineRun\x12T.github.com.metaprov.modelaapi.services.datapipelinerun.v1.GetDataPipelineRunRequest\x1aU.github.com.metaprov.modelaapi.services.datapipelinerun.v1.GetDataPipelineRunResponse\"/\x82\xd3\xe4\x93\x02)\x12\'/v1/datapipelineruns/{namespace}/{name}\x12\xb0\x02\n\x15UpdateDataPipelineRun\x12W.github.com.metaprov.modelaapi.services.datapipelinerun.v1.UpdateDataPipelineRunRequest\x1aX.github.com.metaprov.modelaapi.services.datapipelinerun.v1.UpdateDataPipelineRunResponse\"d\x82\xd3\xe4\x93\x02^\x1aY/v1/datapipelineruns/{datapipelinerun.metadata.namespace}/{datapipelinerun.metadata.name}:\x01*\x12\xff\x01\n\x15\x44\x65leteDataPipelineRun\x12W.github.com.metaprov.modelaapi.services.datapipelinerun.v1.DeleteDataPipelineRunRequest\x1aX.github.com.metaprov.modelaapi.services.datapipelinerun.v1.DeleteDataPipelineRunResponse\"3\x82\xd3\xe4\x93\x02-*+/api/v1/datapipelineruns/{namespace}/{name}\x12\xfe\x01\n\x14\x41\x62ortDataPipelineRun\x12V.github.com.metaprov.modelaapi.services.datapipelinerun.v1.AbortDataPipelineRunRequest\x1aW.github.com.metaprov.modelaapi.services.datapipelinerun.v1.AbortDataPipelineRunResponse\"5\x82\xd3\xe4\x93\x02/\"-/v1/datapipelineruns/{namespace}/{name}:abort\x12\xfb\x01\n\x14PauseDataPipelineRun\x12V.github.com.metaprov.modelaapi.services.datapipelinerun.v1.PauseDataPipelineRunRequest\x1aW.github.com.metaprov.modelaapi.services.datapipelinerun.v1.PauseDataPipelineRunResponse\"2\x82\xd3\xe4\x93\x02,\"*/v1/datapipelines/{namespace}/{name}:pause\x12\xff\x01\n\x15ResumeDataPipelineRun\x12W.github.com.metaprov.modelaapi.services.datapipelinerun.v1.ResumeDataPipelineRunRequest\x1aX.github.com.metaprov.modelaapi.services.datapipelinerun.v1.ResumeDataPipelineRunResponse\"3\x82\xd3\xe4\x93\x02-\"+/v1/datapipelines/{namespace}/{name}:resumeB;Z9github.com/metaprov/modelaapi/services/datapipelinerun/v1b\x06proto3')



_LISTDATAPIPELINERUNREQUEST = DESCRIPTOR.message_types_by_name['ListDataPipelineRunRequest']
_LISTDATAPIPELINERUNREQUEST_LABELSENTRY = _LISTDATAPIPELINERUNREQUEST.nested_types_by_name['LabelsEntry']
_LISTDATAPIPELINERUNRESPONSE = DESCRIPTOR.message_types_by_name['ListDataPipelineRunResponse']
_CREATEDATAPIPELINERUNREQUEST = DESCRIPTOR.message_types_by_name['CreateDataPipelineRunRequest']
_CREATEDATAPIPELINERUNRESPONSE = DESCRIPTOR.message_types_by_name['CreateDataPipelineRunResponse']
_UPDATEDATAPIPELINERUNREQUEST = DESCRIPTOR.message_types_by_name['UpdateDataPipelineRunRequest']
_UPDATEDATAPIPELINERUNRESPONSE = DESCRIPTOR.message_types_by_name['UpdateDataPipelineRunResponse']
_GETDATAPIPELINERUNREQUEST = DESCRIPTOR.message_types_by_name['GetDataPipelineRunRequest']
_GETDATAPIPELINERUNRESPONSE = DESCRIPTOR.message_types_by_name['GetDataPipelineRunResponse']
_DELETEDATAPIPELINERUNREQUEST = DESCRIPTOR.message_types_by_name['DeleteDataPipelineRunRequest']
_DELETEDATAPIPELINERUNRESPONSE = DESCRIPTOR.message_types_by_name['DeleteDataPipelineRunResponse']
_ABORTDATAPIPELINERUNRESPONSE = DESCRIPTOR.message_types_by_name['AbortDataPipelineRunResponse']
_ABORTDATAPIPELINERUNREQUEST = DESCRIPTOR.message_types_by_name['AbortDataPipelineRunRequest']
_PAUSEDATAPIPELINERUNRESPONSE = DESCRIPTOR.message_types_by_name['PauseDataPipelineRunResponse']
_PAUSEDATAPIPELINERUNREQUEST = DESCRIPTOR.message_types_by_name['PauseDataPipelineRunRequest']
_RESUMEDATAPIPELINERUNRESPONSE = DESCRIPTOR.message_types_by_name['ResumeDataPipelineRunResponse']
_RESUMEDATAPIPELINERUNREQUEST = DESCRIPTOR.message_types_by_name['ResumeDataPipelineRunRequest']
ListDataPipelineRunRequest = _reflection.GeneratedProtocolMessageType('ListDataPipelineRunRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _LISTDATAPIPELINERUNREQUEST_LABELSENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.datapipelinerun.v1.datapipelinerun_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.datapipelinerun.v1.ListDataPipelineRunRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _LISTDATAPIPELINERUNREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.datapipelinerun.v1.datapipelinerun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.datapipelinerun.v1.ListDataPipelineRunRequest)
  })
_sym_db.RegisterMessage(ListDataPipelineRunRequest)
_sym_db.RegisterMessage(ListDataPipelineRunRequest.LabelsEntry)

ListDataPipelineRunResponse = _reflection.GeneratedProtocolMessageType('ListDataPipelineRunResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTDATAPIPELINERUNRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.datapipelinerun.v1.datapipelinerun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.datapipelinerun.v1.ListDataPipelineRunResponse)
  })
_sym_db.RegisterMessage(ListDataPipelineRunResponse)

CreateDataPipelineRunRequest = _reflection.GeneratedProtocolMessageType('CreateDataPipelineRunRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEDATAPIPELINERUNREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.datapipelinerun.v1.datapipelinerun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.datapipelinerun.v1.CreateDataPipelineRunRequest)
  })
_sym_db.RegisterMessage(CreateDataPipelineRunRequest)

CreateDataPipelineRunResponse = _reflection.GeneratedProtocolMessageType('CreateDataPipelineRunResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATEDATAPIPELINERUNRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.datapipelinerun.v1.datapipelinerun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.datapipelinerun.v1.CreateDataPipelineRunResponse)
  })
_sym_db.RegisterMessage(CreateDataPipelineRunResponse)

UpdateDataPipelineRunRequest = _reflection.GeneratedProtocolMessageType('UpdateDataPipelineRunRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEDATAPIPELINERUNREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.datapipelinerun.v1.datapipelinerun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.datapipelinerun.v1.UpdateDataPipelineRunRequest)
  })
_sym_db.RegisterMessage(UpdateDataPipelineRunRequest)

UpdateDataPipelineRunResponse = _reflection.GeneratedProtocolMessageType('UpdateDataPipelineRunResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEDATAPIPELINERUNRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.datapipelinerun.v1.datapipelinerun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.datapipelinerun.v1.UpdateDataPipelineRunResponse)
  })
_sym_db.RegisterMessage(UpdateDataPipelineRunResponse)

GetDataPipelineRunRequest = _reflection.GeneratedProtocolMessageType('GetDataPipelineRunRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETDATAPIPELINERUNREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.datapipelinerun.v1.datapipelinerun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.datapipelinerun.v1.GetDataPipelineRunRequest)
  })
_sym_db.RegisterMessage(GetDataPipelineRunRequest)

GetDataPipelineRunResponse = _reflection.GeneratedProtocolMessageType('GetDataPipelineRunResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETDATAPIPELINERUNRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.datapipelinerun.v1.datapipelinerun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.datapipelinerun.v1.GetDataPipelineRunResponse)
  })
_sym_db.RegisterMessage(GetDataPipelineRunResponse)

DeleteDataPipelineRunRequest = _reflection.GeneratedProtocolMessageType('DeleteDataPipelineRunRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEDATAPIPELINERUNREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.datapipelinerun.v1.datapipelinerun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.datapipelinerun.v1.DeleteDataPipelineRunRequest)
  })
_sym_db.RegisterMessage(DeleteDataPipelineRunRequest)

DeleteDataPipelineRunResponse = _reflection.GeneratedProtocolMessageType('DeleteDataPipelineRunResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETEDATAPIPELINERUNRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.datapipelinerun.v1.datapipelinerun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.datapipelinerun.v1.DeleteDataPipelineRunResponse)
  })
_sym_db.RegisterMessage(DeleteDataPipelineRunResponse)

AbortDataPipelineRunResponse = _reflection.GeneratedProtocolMessageType('AbortDataPipelineRunResponse', (_message.Message,), {
  'DESCRIPTOR' : _ABORTDATAPIPELINERUNRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.datapipelinerun.v1.datapipelinerun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.datapipelinerun.v1.AbortDataPipelineRunResponse)
  })
_sym_db.RegisterMessage(AbortDataPipelineRunResponse)

AbortDataPipelineRunRequest = _reflection.GeneratedProtocolMessageType('AbortDataPipelineRunRequest', (_message.Message,), {
  'DESCRIPTOR' : _ABORTDATAPIPELINERUNREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.datapipelinerun.v1.datapipelinerun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.datapipelinerun.v1.AbortDataPipelineRunRequest)
  })
_sym_db.RegisterMessage(AbortDataPipelineRunRequest)

PauseDataPipelineRunResponse = _reflection.GeneratedProtocolMessageType('PauseDataPipelineRunResponse', (_message.Message,), {
  'DESCRIPTOR' : _PAUSEDATAPIPELINERUNRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.datapipelinerun.v1.datapipelinerun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.datapipelinerun.v1.PauseDataPipelineRunResponse)
  })
_sym_db.RegisterMessage(PauseDataPipelineRunResponse)

PauseDataPipelineRunRequest = _reflection.GeneratedProtocolMessageType('PauseDataPipelineRunRequest', (_message.Message,), {
  'DESCRIPTOR' : _PAUSEDATAPIPELINERUNREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.datapipelinerun.v1.datapipelinerun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.datapipelinerun.v1.PauseDataPipelineRunRequest)
  })
_sym_db.RegisterMessage(PauseDataPipelineRunRequest)

ResumeDataPipelineRunResponse = _reflection.GeneratedProtocolMessageType('ResumeDataPipelineRunResponse', (_message.Message,), {
  'DESCRIPTOR' : _RESUMEDATAPIPELINERUNRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.datapipelinerun.v1.datapipelinerun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.datapipelinerun.v1.ResumeDataPipelineRunResponse)
  })
_sym_db.RegisterMessage(ResumeDataPipelineRunResponse)

ResumeDataPipelineRunRequest = _reflection.GeneratedProtocolMessageType('ResumeDataPipelineRunRequest', (_message.Message,), {
  'DESCRIPTOR' : _RESUMEDATAPIPELINERUNREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.datapipelinerun.v1.datapipelinerun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.datapipelinerun.v1.ResumeDataPipelineRunRequest)
  })
_sym_db.RegisterMessage(ResumeDataPipelineRunRequest)

_DATAPIPELINERUNSERVICE = DESCRIPTOR.services_by_name['DataPipelineRunService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z9github.com/metaprov/modelaapi/services/datapipelinerun/v1'
  _LISTDATAPIPELINERUNREQUEST_LABELSENTRY._options = None
  _LISTDATAPIPELINERUNREQUEST_LABELSENTRY._serialized_options = b'8\001'
  _DATAPIPELINERUNSERVICE.methods_by_name['ListDataPipelineRuns']._options = None
  _DATAPIPELINERUNSERVICE.methods_by_name['ListDataPipelineRuns']._serialized_options = b'\202\323\344\223\002\"\022 /v1/datapipelineruns/{namespace}'
  _DATAPIPELINERUNSERVICE.methods_by_name['CreateDataPipelineRun']._options = None
  _DATAPIPELINERUNSERVICE.methods_by_name['CreateDataPipelineRun']._serialized_options = b'\202\323\344\223\002\031\"\024/v1/datapipelineruns:\001*'
  _DATAPIPELINERUNSERVICE.methods_by_name['GetDataPipelineRun']._options = None
  _DATAPIPELINERUNSERVICE.methods_by_name['GetDataPipelineRun']._serialized_options = b'\202\323\344\223\002)\022\'/v1/datapipelineruns/{namespace}/{name}'
  _DATAPIPELINERUNSERVICE.methods_by_name['UpdateDataPipelineRun']._options = None
  _DATAPIPELINERUNSERVICE.methods_by_name['UpdateDataPipelineRun']._serialized_options = b'\202\323\344\223\002^\032Y/v1/datapipelineruns/{datapipelinerun.metadata.namespace}/{datapipelinerun.metadata.name}:\001*'
  _DATAPIPELINERUNSERVICE.methods_by_name['DeleteDataPipelineRun']._options = None
  _DATAPIPELINERUNSERVICE.methods_by_name['DeleteDataPipelineRun']._serialized_options = b'\202\323\344\223\002-*+/api/v1/datapipelineruns/{namespace}/{name}'
  _DATAPIPELINERUNSERVICE.methods_by_name['AbortDataPipelineRun']._options = None
  _DATAPIPELINERUNSERVICE.methods_by_name['AbortDataPipelineRun']._serialized_options = b'\202\323\344\223\002/\"-/v1/datapipelineruns/{namespace}/{name}:abort'
  _DATAPIPELINERUNSERVICE.methods_by_name['PauseDataPipelineRun']._options = None
  _DATAPIPELINERUNSERVICE.methods_by_name['PauseDataPipelineRun']._serialized_options = b'\202\323\344\223\002,\"*/v1/datapipelines/{namespace}/{name}:pause'
  _DATAPIPELINERUNSERVICE.methods_by_name['ResumeDataPipelineRun']._options = None
  _DATAPIPELINERUNSERVICE.methods_by_name['ResumeDataPipelineRun']._serialized_options = b'\202\323\344\223\002-\"+/v1/datapipelines/{namespace}/{name}:resume'
  _LISTDATAPIPELINERUNREQUEST._serialized_start=277
  _LISTDATAPIPELINERUNREQUEST._serialized_end=543
  _LISTDATAPIPELINERUNREQUEST_LABELSENTRY._serialized_start=498
  _LISTDATAPIPELINERUNREQUEST_LABELSENTRY._serialized_end=543
  _LISTDATAPIPELINERUNRESPONSE._serialized_start=546
  _LISTDATAPIPELINERUNRESPONSE._serialized_end=701
  _CREATEDATAPIPELINERUNREQUEST._serialized_start=703
  _CREATEDATAPIPELINERUNREQUEST._serialized_end=829
  _CREATEDATAPIPELINERUNRESPONSE._serialized_start=831
  _CREATEDATAPIPELINERUNRESPONSE._serialized_end=862
  _UPDATEDATAPIPELINERUNREQUEST._serialized_start=865
  _UPDATEDATAPIPELINERUNREQUEST._serialized_end=1039
  _UPDATEDATAPIPELINERUNRESPONSE._serialized_start=1041
  _UPDATEDATAPIPELINERUNRESPONSE._serialized_end=1072
  _GETDATAPIPELINERUNREQUEST._serialized_start=1074
  _GETDATAPIPELINERUNREQUEST._serialized_end=1134
  _GETDATAPIPELINERUNRESPONSE._serialized_start=1137
  _GETDATAPIPELINERUNRESPONSE._serialized_end=1275
  _DELETEDATAPIPELINERUNREQUEST._serialized_start=1277
  _DELETEDATAPIPELINERUNREQUEST._serialized_end=1340
  _DELETEDATAPIPELINERUNRESPONSE._serialized_start=1342
  _DELETEDATAPIPELINERUNRESPONSE._serialized_end=1373
  _ABORTDATAPIPELINERUNRESPONSE._serialized_start=1375
  _ABORTDATAPIPELINERUNRESPONSE._serialized_end=1405
  _ABORTDATAPIPELINERUNREQUEST._serialized_start=1407
  _ABORTDATAPIPELINERUNREQUEST._serialized_end=1469
  _PAUSEDATAPIPELINERUNRESPONSE._serialized_start=1471
  _PAUSEDATAPIPELINERUNRESPONSE._serialized_end=1501
  _PAUSEDATAPIPELINERUNREQUEST._serialized_start=1503
  _PAUSEDATAPIPELINERUNREQUEST._serialized_end=1565
  _RESUMEDATAPIPELINERUNRESPONSE._serialized_start=1567
  _RESUMEDATAPIPELINERUNRESPONSE._serialized_end=1598
  _RESUMEDATAPIPELINERUNREQUEST._serialized_start=1600
  _RESUMEDATAPIPELINERUNREQUEST._serialized_end=1663
  _DATAPIPELINERUNSERVICE._serialized_start=1666
  _DATAPIPELINERUNSERVICE._serialized_end=3749
# @@protoc_insertion_point(module_scope)
