# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from github.com.metaprov.modelaapi.services.tenant.v1 import tenant_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_tenant_dot_v1_dot_tenant__pb2


class TenantServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.ListTenants = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.tenant.v1.TenantService/ListTenants',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_tenant_dot_v1_dot_tenant__pb2.ListTenantsRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_tenant_dot_v1_dot_tenant__pb2.ListTenantsResponse.FromString,
                )
        self.CreateTenant = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.tenant.v1.TenantService/CreateTenant',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_tenant_dot_v1_dot_tenant__pb2.CreateTenantRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_tenant_dot_v1_dot_tenant__pb2.CreateTenantResponse.FromString,
                )
        self.GetTenant = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.tenant.v1.TenantService/GetTenant',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_tenant_dot_v1_dot_tenant__pb2.GetTenantRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_tenant_dot_v1_dot_tenant__pb2.GetTenantResponse.FromString,
                )
        self.UpdateTenant = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.tenant.v1.TenantService/UpdateTenant',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_tenant_dot_v1_dot_tenant__pb2.UpdateTenantRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_tenant_dot_v1_dot_tenant__pb2.UpdateTenantResponse.FromString,
                )
        self.DeleteTenant = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.tenant.v1.TenantService/DeleteTenant',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_tenant_dot_v1_dot_tenant__pb2.DeleteTenantRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_tenant_dot_v1_dot_tenant__pb2.DeleteTenantResponse.FromString,
                )


class TenantServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def ListTenants(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateTenant(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetTenant(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateTenant(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteTenant(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_TenantServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'ListTenants': grpc.unary_unary_rpc_method_handler(
                    servicer.ListTenants,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_tenant_dot_v1_dot_tenant__pb2.ListTenantsRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_tenant_dot_v1_dot_tenant__pb2.ListTenantsResponse.SerializeToString,
            ),
            'CreateTenant': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateTenant,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_tenant_dot_v1_dot_tenant__pb2.CreateTenantRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_tenant_dot_v1_dot_tenant__pb2.CreateTenantResponse.SerializeToString,
            ),
            'GetTenant': grpc.unary_unary_rpc_method_handler(
                    servicer.GetTenant,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_tenant_dot_v1_dot_tenant__pb2.GetTenantRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_tenant_dot_v1_dot_tenant__pb2.GetTenantResponse.SerializeToString,
            ),
            'UpdateTenant': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateTenant,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_tenant_dot_v1_dot_tenant__pb2.UpdateTenantRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_tenant_dot_v1_dot_tenant__pb2.UpdateTenantResponse.SerializeToString,
            ),
            'DeleteTenant': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteTenant,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_tenant_dot_v1_dot_tenant__pb2.DeleteTenantRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_tenant_dot_v1_dot_tenant__pb2.DeleteTenantResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'github.com.metaprov.modelaapi.services.tenant.v1.TenantService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class TenantService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def ListTenants(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.tenant.v1.TenantService/ListTenants',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_tenant_dot_v1_dot_tenant__pb2.ListTenantsRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_tenant_dot_v1_dot_tenant__pb2.ListTenantsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateTenant(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.tenant.v1.TenantService/CreateTenant',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_tenant_dot_v1_dot_tenant__pb2.CreateTenantRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_tenant_dot_v1_dot_tenant__pb2.CreateTenantResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetTenant(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.tenant.v1.TenantService/GetTenant',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_tenant_dot_v1_dot_tenant__pb2.GetTenantRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_tenant_dot_v1_dot_tenant__pb2.GetTenantResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateTenant(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.tenant.v1.TenantService/UpdateTenant',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_tenant_dot_v1_dot_tenant__pb2.UpdateTenantRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_tenant_dot_v1_dot_tenant__pb2.UpdateTenantResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteTenant(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.tenant.v1.TenantService/DeleteTenant',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_tenant_dot_v1_dot_tenant__pb2.DeleteTenantRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_tenant_dot_v1_dot_tenant__pb2.DeleteTenantResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
