# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: github.com/metaprov/modelaapi/services/modelautobuilder/v1/modelautobuilder.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1 import generated_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_training_dot_v1alpha1_dot_generated__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nQgithub.com/metaprov/modelaapi/services/modelautobuilder/v1/modelautobuilder.proto\x12:github.com.metaprov.modelaapi.services.modelautobuilder.v1\x1a google/protobuf/field_mask.proto\x1a\x1cgoogle/api/annotations.proto\x1aHgithub.com/metaprov/modelaapi/pkg/apis/training/v1alpha1/generated.proto\"\x8f\x02\n\x1cListModelAutobuildersRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12t\n\x06labels\x18\x02 \x03(\x0b\x32\x64.github.com.metaprov.modelaapi.services.modelautobuilder.v1.ListModelAutobuildersRequest.LabelsEntry\x12\x11\n\tpage_size\x18\x03 \x01(\x05\x12\x12\n\npage_token\x18\x04 \x01(\t\x12\x10\n\x08order_by\x18\x05 \x01(\t\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xa3\x01\n\x1dListModelAutobuildersResponse\x12i\n\x11modelautobuilders\x18\x01 \x01(\x0b\x32N.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.ModelAutobuilderList\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\x85\x01\n\x1d\x43reateModelAutobuilderRequest\x12\x64\n\x10modelautobuilder\x18\x01 \x01(\x0b\x32J.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.ModelAutobuilder\" \n\x1e\x43reateModelAutobuilderResponse\"\xb5\x01\n\x1dUpdateModelAutobuilderRequest\x12\x64\n\x10modelautobuilder\x18\x01 \x01(\x0b\x32J.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.ModelAutobuilder\x12.\n\nfield_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\" \n\x1eUpdateModelAutobuilderResponse\"=\n\x1aGetModelAutobuilderRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x91\x01\n\x1bGetModelAutobuilderResponse\x12\x64\n\x10modelautobuilder\x18\x01 \x01(\x0b\x32J.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.ModelAutobuilder\x12\x0c\n\x04yaml\x18\x02 \x01(\t\"@\n\x1d\x44\x65leteModelAutobuilderRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\" \n\x1e\x44\x65leteModelAutobuilderResponse2\xc1\n\n\x17ModelAutobuilderService\x12\xf7\x01\n\x15ListModelAutobuilders\x12X.github.com.metaprov.modelaapi.services.modelautobuilder.v1.ListModelAutobuildersRequest\x1aY.github.com.metaprov.modelaapi.services.modelautobuilder.v1.ListModelAutobuildersResponse\")\x82\xd3\xe4\x93\x02#\x12!/v1/modelautobuilders/{namespace}\x12\xf1\x01\n\x16\x43reateModelAutobuilder\x12Y.github.com.metaprov.modelaapi.services.modelautobuilder.v1.CreateModelAutobuilderRequest\x1aZ.github.com.metaprov.modelaapi.services.modelautobuilder.v1.CreateModelAutobuilderResponse\" \x82\xd3\xe4\x93\x02\x1a\"\x15/v1/modelautobuilders:\x01*\x12\xf8\x01\n\x13GetModelAutobuilder\x12V.github.com.metaprov.modelaapi.services.modelautobuilder.v1.GetModelAutobuilderRequest\x1aW.github.com.metaprov.modelaapi.services.modelautobuilder.v1.GetModelAutobuilderResponse\"0\x82\xd3\xe4\x93\x02*\x12(/v1/modelautobuilders/{namespace}/{name}\x12\xb8\x02\n\x16UpdateModelAutobuilder\x12Y.github.com.metaprov.modelaapi.services.modelautobuilder.v1.UpdateModelAutobuilderRequest\x1aZ.github.com.metaprov.modelaapi.services.modelautobuilder.v1.UpdateModelAutobuilderResponse\"g\x82\xd3\xe4\x93\x02\x61\x1a\\/v1/modelautobuilders/{modelautobuilder.metadata.namespace}/{modelautobuilder.metadata.name}:\x01*\x12\x81\x02\n\x16\x44\x65leteModelAutobuilder\x12Y.github.com.metaprov.modelaapi.services.modelautobuilder.v1.DeleteModelAutobuilderRequest\x1aZ.github.com.metaprov.modelaapi.services.modelautobuilder.v1.DeleteModelAutobuilderResponse\"0\x82\xd3\xe4\x93\x02**(/v1/modelautobuilders/{namespace}/{name}B<Z:github.com/metaprov/modelaapi/services/modelautobuilder/v1b\x06proto3')



_LISTMODELAUTOBUILDERSREQUEST = DESCRIPTOR.message_types_by_name['ListModelAutobuildersRequest']
_LISTMODELAUTOBUILDERSREQUEST_LABELSENTRY = _LISTMODELAUTOBUILDERSREQUEST.nested_types_by_name['LabelsEntry']
_LISTMODELAUTOBUILDERSRESPONSE = DESCRIPTOR.message_types_by_name['ListModelAutobuildersResponse']
_CREATEMODELAUTOBUILDERREQUEST = DESCRIPTOR.message_types_by_name['CreateModelAutobuilderRequest']
_CREATEMODELAUTOBUILDERRESPONSE = DESCRIPTOR.message_types_by_name['CreateModelAutobuilderResponse']
_UPDATEMODELAUTOBUILDERREQUEST = DESCRIPTOR.message_types_by_name['UpdateModelAutobuilderRequest']
_UPDATEMODELAUTOBUILDERRESPONSE = DESCRIPTOR.message_types_by_name['UpdateModelAutobuilderResponse']
_GETMODELAUTOBUILDERREQUEST = DESCRIPTOR.message_types_by_name['GetModelAutobuilderRequest']
_GETMODELAUTOBUILDERRESPONSE = DESCRIPTOR.message_types_by_name['GetModelAutobuilderResponse']
_DELETEMODELAUTOBUILDERREQUEST = DESCRIPTOR.message_types_by_name['DeleteModelAutobuilderRequest']
_DELETEMODELAUTOBUILDERRESPONSE = DESCRIPTOR.message_types_by_name['DeleteModelAutobuilderResponse']
ListModelAutobuildersRequest = _reflection.GeneratedProtocolMessageType('ListModelAutobuildersRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _LISTMODELAUTOBUILDERSREQUEST_LABELSENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.modelautobuilder.v1.modelautobuilder_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelautobuilder.v1.ListModelAutobuildersRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _LISTMODELAUTOBUILDERSREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelautobuilder.v1.modelautobuilder_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelautobuilder.v1.ListModelAutobuildersRequest)
  })
_sym_db.RegisterMessage(ListModelAutobuildersRequest)
_sym_db.RegisterMessage(ListModelAutobuildersRequest.LabelsEntry)

ListModelAutobuildersResponse = _reflection.GeneratedProtocolMessageType('ListModelAutobuildersResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTMODELAUTOBUILDERSRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelautobuilder.v1.modelautobuilder_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelautobuilder.v1.ListModelAutobuildersResponse)
  })
_sym_db.RegisterMessage(ListModelAutobuildersResponse)

CreateModelAutobuilderRequest = _reflection.GeneratedProtocolMessageType('CreateModelAutobuilderRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEMODELAUTOBUILDERREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelautobuilder.v1.modelautobuilder_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelautobuilder.v1.CreateModelAutobuilderRequest)
  })
_sym_db.RegisterMessage(CreateModelAutobuilderRequest)

CreateModelAutobuilderResponse = _reflection.GeneratedProtocolMessageType('CreateModelAutobuilderResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATEMODELAUTOBUILDERRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelautobuilder.v1.modelautobuilder_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelautobuilder.v1.CreateModelAutobuilderResponse)
  })
_sym_db.RegisterMessage(CreateModelAutobuilderResponse)

UpdateModelAutobuilderRequest = _reflection.GeneratedProtocolMessageType('UpdateModelAutobuilderRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEMODELAUTOBUILDERREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelautobuilder.v1.modelautobuilder_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelautobuilder.v1.UpdateModelAutobuilderRequest)
  })
_sym_db.RegisterMessage(UpdateModelAutobuilderRequest)

UpdateModelAutobuilderResponse = _reflection.GeneratedProtocolMessageType('UpdateModelAutobuilderResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEMODELAUTOBUILDERRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelautobuilder.v1.modelautobuilder_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelautobuilder.v1.UpdateModelAutobuilderResponse)
  })
_sym_db.RegisterMessage(UpdateModelAutobuilderResponse)

GetModelAutobuilderRequest = _reflection.GeneratedProtocolMessageType('GetModelAutobuilderRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETMODELAUTOBUILDERREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelautobuilder.v1.modelautobuilder_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelautobuilder.v1.GetModelAutobuilderRequest)
  })
_sym_db.RegisterMessage(GetModelAutobuilderRequest)

GetModelAutobuilderResponse = _reflection.GeneratedProtocolMessageType('GetModelAutobuilderResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETMODELAUTOBUILDERRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelautobuilder.v1.modelautobuilder_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelautobuilder.v1.GetModelAutobuilderResponse)
  })
_sym_db.RegisterMessage(GetModelAutobuilderResponse)

DeleteModelAutobuilderRequest = _reflection.GeneratedProtocolMessageType('DeleteModelAutobuilderRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEMODELAUTOBUILDERREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelautobuilder.v1.modelautobuilder_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelautobuilder.v1.DeleteModelAutobuilderRequest)
  })
_sym_db.RegisterMessage(DeleteModelAutobuilderRequest)

DeleteModelAutobuilderResponse = _reflection.GeneratedProtocolMessageType('DeleteModelAutobuilderResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETEMODELAUTOBUILDERRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelautobuilder.v1.modelautobuilder_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelautobuilder.v1.DeleteModelAutobuilderResponse)
  })
_sym_db.RegisterMessage(DeleteModelAutobuilderResponse)

_MODELAUTOBUILDERSERVICE = DESCRIPTOR.services_by_name['ModelAutobuilderService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z:github.com/metaprov/modelaapi/services/modelautobuilder/v1'
  _LISTMODELAUTOBUILDERSREQUEST_LABELSENTRY._options = None
  _LISTMODELAUTOBUILDERSREQUEST_LABELSENTRY._serialized_options = b'8\001'
  _MODELAUTOBUILDERSERVICE.methods_by_name['ListModelAutobuilders']._options = None
  _MODELAUTOBUILDERSERVICE.methods_by_name['ListModelAutobuilders']._serialized_options = b'\202\323\344\223\002#\022!/v1/modelautobuilders/{namespace}'
  _MODELAUTOBUILDERSERVICE.methods_by_name['CreateModelAutobuilder']._options = None
  _MODELAUTOBUILDERSERVICE.methods_by_name['CreateModelAutobuilder']._serialized_options = b'\202\323\344\223\002\032\"\025/v1/modelautobuilders:\001*'
  _MODELAUTOBUILDERSERVICE.methods_by_name['GetModelAutobuilder']._options = None
  _MODELAUTOBUILDERSERVICE.methods_by_name['GetModelAutobuilder']._serialized_options = b'\202\323\344\223\002*\022(/v1/modelautobuilders/{namespace}/{name}'
  _MODELAUTOBUILDERSERVICE.methods_by_name['UpdateModelAutobuilder']._options = None
  _MODELAUTOBUILDERSERVICE.methods_by_name['UpdateModelAutobuilder']._serialized_options = b'\202\323\344\223\002a\032\\/v1/modelautobuilders/{modelautobuilder.metadata.namespace}/{modelautobuilder.metadata.name}:\001*'
  _MODELAUTOBUILDERSERVICE.methods_by_name['DeleteModelAutobuilder']._options = None
  _MODELAUTOBUILDERSERVICE.methods_by_name['DeleteModelAutobuilder']._serialized_options = b'\202\323\344\223\002**(/v1/modelautobuilders/{namespace}/{name}'
  _LISTMODELAUTOBUILDERSREQUEST._serialized_start=284
  _LISTMODELAUTOBUILDERSREQUEST._serialized_end=555
  _LISTMODELAUTOBUILDERSREQUEST_LABELSENTRY._serialized_start=510
  _LISTMODELAUTOBUILDERSREQUEST_LABELSENTRY._serialized_end=555
  _LISTMODELAUTOBUILDERSRESPONSE._serialized_start=558
  _LISTMODELAUTOBUILDERSRESPONSE._serialized_end=721
  _CREATEMODELAUTOBUILDERREQUEST._serialized_start=724
  _CREATEMODELAUTOBUILDERREQUEST._serialized_end=857
  _CREATEMODELAUTOBUILDERRESPONSE._serialized_start=859
  _CREATEMODELAUTOBUILDERRESPONSE._serialized_end=891
  _UPDATEMODELAUTOBUILDERREQUEST._serialized_start=894
  _UPDATEMODELAUTOBUILDERREQUEST._serialized_end=1075
  _UPDATEMODELAUTOBUILDERRESPONSE._serialized_start=1077
  _UPDATEMODELAUTOBUILDERRESPONSE._serialized_end=1109
  _GETMODELAUTOBUILDERREQUEST._serialized_start=1111
  _GETMODELAUTOBUILDERREQUEST._serialized_end=1172
  _GETMODELAUTOBUILDERRESPONSE._serialized_start=1175
  _GETMODELAUTOBUILDERRESPONSE._serialized_end=1320
  _DELETEMODELAUTOBUILDERREQUEST._serialized_start=1322
  _DELETEMODELAUTOBUILDERREQUEST._serialized_end=1386
  _DELETEMODELAUTOBUILDERRESPONSE._serialized_start=1388
  _DELETEMODELAUTOBUILDERRESPONSE._serialized_end=1420
  _MODELAUTOBUILDERSERVICE._serialized_start=1423
  _MODELAUTOBUILDERSERVICE._serialized_end=2768
# @@protoc_insertion_point(module_scope)
