# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from github.com.metaprov.modelaapi.services.featurepipelinerun.v1 import featurepipelinerun_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_featurepipelinerun_dot_v1_dot_featurepipelinerun__pb2


class FeaturePipelineRunServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.ListFeaturePipelineRuns = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.featurepipelinerun.v1.FeaturePipelineRunService/ListFeaturePipelineRuns',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_featurepipelinerun_dot_v1_dot_featurepipelinerun__pb2.ListFeaturePipelineRunRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_featurepipelinerun_dot_v1_dot_featurepipelinerun__pb2.ListFeaturePipelineRunResponse.FromString,
                )
        self.CreateFeaturePipelineRun = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.featurepipelinerun.v1.FeaturePipelineRunService/CreateFeaturePipelineRun',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_featurepipelinerun_dot_v1_dot_featurepipelinerun__pb2.CreateFeaturePipelineRunRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_featurepipelinerun_dot_v1_dot_featurepipelinerun__pb2.CreateFeaturePipelineRunResponse.FromString,
                )
        self.GetFeaturePipelineRun = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.featurepipelinerun.v1.FeaturePipelineRunService/GetFeaturePipelineRun',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_featurepipelinerun_dot_v1_dot_featurepipelinerun__pb2.GetFeaturePipelineRunRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_featurepipelinerun_dot_v1_dot_featurepipelinerun__pb2.GetFeaturePipelineRunResponse.FromString,
                )
        self.UpdateFeaturePipelineRun = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.featurepipelinerun.v1.FeaturePipelineRunService/UpdateFeaturePipelineRun',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_featurepipelinerun_dot_v1_dot_featurepipelinerun__pb2.UpdateFeaturePipelineRunRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_featurepipelinerun_dot_v1_dot_featurepipelinerun__pb2.UpdateFeaturePipelineRunResponse.FromString,
                )
        self.DeleteFeaturePipelineRun = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.featurepipelinerun.v1.FeaturePipelineRunService/DeleteFeaturePipelineRun',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_featurepipelinerun_dot_v1_dot_featurepipelinerun__pb2.DeleteFeaturePipelineRunRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_featurepipelinerun_dot_v1_dot_featurepipelinerun__pb2.DeleteFeaturePipelineRunResponse.FromString,
                )


class FeaturePipelineRunServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def ListFeaturePipelineRuns(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateFeaturePipelineRun(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetFeaturePipelineRun(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateFeaturePipelineRun(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteFeaturePipelineRun(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_FeaturePipelineRunServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'ListFeaturePipelineRuns': grpc.unary_unary_rpc_method_handler(
                    servicer.ListFeaturePipelineRuns,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_featurepipelinerun_dot_v1_dot_featurepipelinerun__pb2.ListFeaturePipelineRunRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_featurepipelinerun_dot_v1_dot_featurepipelinerun__pb2.ListFeaturePipelineRunResponse.SerializeToString,
            ),
            'CreateFeaturePipelineRun': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateFeaturePipelineRun,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_featurepipelinerun_dot_v1_dot_featurepipelinerun__pb2.CreateFeaturePipelineRunRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_featurepipelinerun_dot_v1_dot_featurepipelinerun__pb2.CreateFeaturePipelineRunResponse.SerializeToString,
            ),
            'GetFeaturePipelineRun': grpc.unary_unary_rpc_method_handler(
                    servicer.GetFeaturePipelineRun,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_featurepipelinerun_dot_v1_dot_featurepipelinerun__pb2.GetFeaturePipelineRunRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_featurepipelinerun_dot_v1_dot_featurepipelinerun__pb2.GetFeaturePipelineRunResponse.SerializeToString,
            ),
            'UpdateFeaturePipelineRun': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateFeaturePipelineRun,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_featurepipelinerun_dot_v1_dot_featurepipelinerun__pb2.UpdateFeaturePipelineRunRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_featurepipelinerun_dot_v1_dot_featurepipelinerun__pb2.UpdateFeaturePipelineRunResponse.SerializeToString,
            ),
            'DeleteFeaturePipelineRun': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteFeaturePipelineRun,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_featurepipelinerun_dot_v1_dot_featurepipelinerun__pb2.DeleteFeaturePipelineRunRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_featurepipelinerun_dot_v1_dot_featurepipelinerun__pb2.DeleteFeaturePipelineRunResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'github.com.metaprov.modelaapi.services.featurepipelinerun.v1.FeaturePipelineRunService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class FeaturePipelineRunService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def ListFeaturePipelineRuns(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.featurepipelinerun.v1.FeaturePipelineRunService/ListFeaturePipelineRuns',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_featurepipelinerun_dot_v1_dot_featurepipelinerun__pb2.ListFeaturePipelineRunRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_featurepipelinerun_dot_v1_dot_featurepipelinerun__pb2.ListFeaturePipelineRunResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateFeaturePipelineRun(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.featurepipelinerun.v1.FeaturePipelineRunService/CreateFeaturePipelineRun',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_featurepipelinerun_dot_v1_dot_featurepipelinerun__pb2.CreateFeaturePipelineRunRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_featurepipelinerun_dot_v1_dot_featurepipelinerun__pb2.CreateFeaturePipelineRunResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetFeaturePipelineRun(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.featurepipelinerun.v1.FeaturePipelineRunService/GetFeaturePipelineRun',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_featurepipelinerun_dot_v1_dot_featurepipelinerun__pb2.GetFeaturePipelineRunRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_featurepipelinerun_dot_v1_dot_featurepipelinerun__pb2.GetFeaturePipelineRunResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateFeaturePipelineRun(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.featurepipelinerun.v1.FeaturePipelineRunService/UpdateFeaturePipelineRun',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_featurepipelinerun_dot_v1_dot_featurepipelinerun__pb2.UpdateFeaturePipelineRunRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_featurepipelinerun_dot_v1_dot_featurepipelinerun__pb2.UpdateFeaturePipelineRunResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteFeaturePipelineRun(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.featurepipelinerun.v1.FeaturePipelineRunService/DeleteFeaturePipelineRun',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_featurepipelinerun_dot_v1_dot_featurepipelinerun__pb2.DeleteFeaturePipelineRunRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_featurepipelinerun_dot_v1_dot_featurepipelinerun__pb2.DeleteFeaturePipelineRunResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
