# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: github.com/metaprov/modelaapi/services/featurepipeline/v1/featurepipeline.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1 import generated_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nOgithub.com/metaprov/modelaapi/services/featurepipeline/v1/featurepipeline.proto\x12\x39github.com.metaprov.modelaapi.services.featurepipeline.v1\x1a google/protobuf/field_mask.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x44github.com/metaprov/modelaapi/pkg/apis/data/v1alpha1/generated.proto\"\x8a\x02\n\x1aListFeaturePipelineRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12q\n\x06labels\x18\x02 \x03(\x0b\x32\x61.github.com.metaprov.modelaapi.services.featurepipeline.v1.ListFeaturePipelineRequest.LabelsEntry\x12\x11\n\tpage_size\x18\x03 \x01(\x05\x12\x12\n\npage_token\x18\x04 \x01(\t\x12\x10\n\x08order_by\x18\x05 \x01(\t\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x9b\x01\n\x1bListFeaturePipelineResponse\x12\x63\n\x10\x66\x65\x61turepipelines\x18\x01 \x01(\x0b\x32I.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.FeaturePipelineList\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"~\n\x1c\x43reateFeaturePipelineRequest\x12^\n\x0f\x66\x65\x61turepipeline\x18\x01 \x01(\x0b\x32\x45.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.FeaturePipeline\"\x1f\n\x1d\x43reateFeaturePipelineResponse\"\xae\x01\n\x1cUpdateFeaturePipelineRequest\x12^\n\x0f\x66\x65\x61turepipeline\x18\x01 \x01(\x0b\x32\x45.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.FeaturePipeline\x12.\n\nfield_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\"\x1f\n\x1dUpdateFeaturePipelineResponse\"<\n\x19GetFeaturePipelineRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x8a\x01\n\x1aGetFeaturePipelineResponse\x12^\n\x0f\x66\x65\x61turepipeline\x18\x01 \x01(\x0b\x32\x45.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.FeaturePipeline\x12\x0c\n\x04yaml\x18\x02 \x01(\t\"?\n\x1c\x44\x65leteFeaturePipelineRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x1f\n\x1d\x44\x65leteFeaturePipelineResponse\"\x1e\n\x1cPauseFeaturePipelineResponse\">\n\x1bPauseFeaturePipelineRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x1f\n\x1dResumeFeaturePipelineResponse\"?\n\x1cResumeFeaturePipelineRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t2\xa3\x0e\n\x16\x46\x65\x61turePipelineService\x12\xef\x01\n\x14ListFeaturePipelines\x12U.github.com.metaprov.modelaapi.services.featurepipeline.v1.ListFeaturePipelineRequest\x1aV.github.com.metaprov.modelaapi.services.featurepipeline.v1.ListFeaturePipelineResponse\"(\x82\xd3\xe4\x93\x02\"\x12 /v1/featurepipelines/{namespace}\x12\xeb\x01\n\x15\x43reateFeaturePipeline\x12W.github.com.metaprov.modelaapi.services.featurepipeline.v1.CreateFeaturePipelineRequest\x1aX.github.com.metaprov.modelaapi.services.featurepipeline.v1.CreateFeaturePipelineResponse\"\x1f\x82\xd3\xe4\x93\x02\x19\"\x14/v1/featurepipelines:\x01*\x12\xf2\x01\n\x12GetFeaturePipeline\x12T.github.com.metaprov.modelaapi.services.featurepipeline.v1.GetFeaturePipelineRequest\x1aU.github.com.metaprov.modelaapi.services.featurepipeline.v1.GetFeaturePipelineResponse\"/\x82\xd3\xe4\x93\x02)\x12\'/v1/featurepipelines/{namespace}/{name}\x12\xb0\x02\n\x15UpdateFeaturePipeline\x12W.github.com.metaprov.modelaapi.services.featurepipeline.v1.UpdateFeaturePipelineRequest\x1aX.github.com.metaprov.modelaapi.services.featurepipeline.v1.UpdateFeaturePipelineResponse\"d\x82\xd3\xe4\x93\x02^\x1aY/v1/featurepipelines/{featurepipeline.metadata.namespace}/{featurepipeline.metadata.name}:\x01*\x12\xfb\x01\n\x15\x44\x65leteFeaturePipeline\x12W.github.com.metaprov.modelaapi.services.featurepipeline.v1.DeleteFeaturePipelineRequest\x1aX.github.com.metaprov.modelaapi.services.featurepipeline.v1.DeleteFeaturePipelineResponse\"/\x82\xd3\xe4\x93\x02)*\'/v1/featurepipelines/{namespace}/{name}\x12\xfe\x01\n\x14PauseFeaturePipeline\x12V.github.com.metaprov.modelaapi.services.featurepipeline.v1.PauseFeaturePipelineRequest\x1aW.github.com.metaprov.modelaapi.services.featurepipeline.v1.PauseFeaturePipelineResponse\"5\x82\xd3\xe4\x93\x02/\"-/v1/featurepipelines/{namespace}/{name}:pause\x12\x81\x02\n\x15ResumeFeaturePipeline\x12W.github.com.metaprov.modelaapi.services.featurepipeline.v1.ResumeFeaturePipelineRequest\x1aX.github.com.metaprov.modelaapi.services.featurepipeline.v1.ResumeFeaturePipelineResponse\"5\x82\xd3\xe4\x93\x02/\"-/v1/featurepipelines/{namespace}/{name}:pauseB;Z9github.com/metaprov/modelaapi/services/featurepipeline/v1b\x06proto3')



_LISTFEATUREPIPELINEREQUEST = DESCRIPTOR.message_types_by_name['ListFeaturePipelineRequest']
_LISTFEATUREPIPELINEREQUEST_LABELSENTRY = _LISTFEATUREPIPELINEREQUEST.nested_types_by_name['LabelsEntry']
_LISTFEATUREPIPELINERESPONSE = DESCRIPTOR.message_types_by_name['ListFeaturePipelineResponse']
_CREATEFEATUREPIPELINEREQUEST = DESCRIPTOR.message_types_by_name['CreateFeaturePipelineRequest']
_CREATEFEATUREPIPELINERESPONSE = DESCRIPTOR.message_types_by_name['CreateFeaturePipelineResponse']
_UPDATEFEATUREPIPELINEREQUEST = DESCRIPTOR.message_types_by_name['UpdateFeaturePipelineRequest']
_UPDATEFEATUREPIPELINERESPONSE = DESCRIPTOR.message_types_by_name['UpdateFeaturePipelineResponse']
_GETFEATUREPIPELINEREQUEST = DESCRIPTOR.message_types_by_name['GetFeaturePipelineRequest']
_GETFEATUREPIPELINERESPONSE = DESCRIPTOR.message_types_by_name['GetFeaturePipelineResponse']
_DELETEFEATUREPIPELINEREQUEST = DESCRIPTOR.message_types_by_name['DeleteFeaturePipelineRequest']
_DELETEFEATUREPIPELINERESPONSE = DESCRIPTOR.message_types_by_name['DeleteFeaturePipelineResponse']
_PAUSEFEATUREPIPELINERESPONSE = DESCRIPTOR.message_types_by_name['PauseFeaturePipelineResponse']
_PAUSEFEATUREPIPELINEREQUEST = DESCRIPTOR.message_types_by_name['PauseFeaturePipelineRequest']
_RESUMEFEATUREPIPELINERESPONSE = DESCRIPTOR.message_types_by_name['ResumeFeaturePipelineResponse']
_RESUMEFEATUREPIPELINEREQUEST = DESCRIPTOR.message_types_by_name['ResumeFeaturePipelineRequest']
ListFeaturePipelineRequest = _reflection.GeneratedProtocolMessageType('ListFeaturePipelineRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _LISTFEATUREPIPELINEREQUEST_LABELSENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.featurepipeline.v1.featurepipeline_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.featurepipeline.v1.ListFeaturePipelineRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _LISTFEATUREPIPELINEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.featurepipeline.v1.featurepipeline_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.featurepipeline.v1.ListFeaturePipelineRequest)
  })
_sym_db.RegisterMessage(ListFeaturePipelineRequest)
_sym_db.RegisterMessage(ListFeaturePipelineRequest.LabelsEntry)

ListFeaturePipelineResponse = _reflection.GeneratedProtocolMessageType('ListFeaturePipelineResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTFEATUREPIPELINERESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.featurepipeline.v1.featurepipeline_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.featurepipeline.v1.ListFeaturePipelineResponse)
  })
_sym_db.RegisterMessage(ListFeaturePipelineResponse)

CreateFeaturePipelineRequest = _reflection.GeneratedProtocolMessageType('CreateFeaturePipelineRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEFEATUREPIPELINEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.featurepipeline.v1.featurepipeline_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.featurepipeline.v1.CreateFeaturePipelineRequest)
  })
_sym_db.RegisterMessage(CreateFeaturePipelineRequest)

CreateFeaturePipelineResponse = _reflection.GeneratedProtocolMessageType('CreateFeaturePipelineResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATEFEATUREPIPELINERESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.featurepipeline.v1.featurepipeline_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.featurepipeline.v1.CreateFeaturePipelineResponse)
  })
_sym_db.RegisterMessage(CreateFeaturePipelineResponse)

UpdateFeaturePipelineRequest = _reflection.GeneratedProtocolMessageType('UpdateFeaturePipelineRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEFEATUREPIPELINEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.featurepipeline.v1.featurepipeline_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.featurepipeline.v1.UpdateFeaturePipelineRequest)
  })
_sym_db.RegisterMessage(UpdateFeaturePipelineRequest)

UpdateFeaturePipelineResponse = _reflection.GeneratedProtocolMessageType('UpdateFeaturePipelineResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEFEATUREPIPELINERESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.featurepipeline.v1.featurepipeline_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.featurepipeline.v1.UpdateFeaturePipelineResponse)
  })
_sym_db.RegisterMessage(UpdateFeaturePipelineResponse)

GetFeaturePipelineRequest = _reflection.GeneratedProtocolMessageType('GetFeaturePipelineRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETFEATUREPIPELINEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.featurepipeline.v1.featurepipeline_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.featurepipeline.v1.GetFeaturePipelineRequest)
  })
_sym_db.RegisterMessage(GetFeaturePipelineRequest)

GetFeaturePipelineResponse = _reflection.GeneratedProtocolMessageType('GetFeaturePipelineResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETFEATUREPIPELINERESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.featurepipeline.v1.featurepipeline_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.featurepipeline.v1.GetFeaturePipelineResponse)
  })
_sym_db.RegisterMessage(GetFeaturePipelineResponse)

DeleteFeaturePipelineRequest = _reflection.GeneratedProtocolMessageType('DeleteFeaturePipelineRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEFEATUREPIPELINEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.featurepipeline.v1.featurepipeline_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.featurepipeline.v1.DeleteFeaturePipelineRequest)
  })
_sym_db.RegisterMessage(DeleteFeaturePipelineRequest)

DeleteFeaturePipelineResponse = _reflection.GeneratedProtocolMessageType('DeleteFeaturePipelineResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETEFEATUREPIPELINERESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.featurepipeline.v1.featurepipeline_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.featurepipeline.v1.DeleteFeaturePipelineResponse)
  })
_sym_db.RegisterMessage(DeleteFeaturePipelineResponse)

PauseFeaturePipelineResponse = _reflection.GeneratedProtocolMessageType('PauseFeaturePipelineResponse', (_message.Message,), {
  'DESCRIPTOR' : _PAUSEFEATUREPIPELINERESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.featurepipeline.v1.featurepipeline_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.featurepipeline.v1.PauseFeaturePipelineResponse)
  })
_sym_db.RegisterMessage(PauseFeaturePipelineResponse)

PauseFeaturePipelineRequest = _reflection.GeneratedProtocolMessageType('PauseFeaturePipelineRequest', (_message.Message,), {
  'DESCRIPTOR' : _PAUSEFEATUREPIPELINEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.featurepipeline.v1.featurepipeline_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.featurepipeline.v1.PauseFeaturePipelineRequest)
  })
_sym_db.RegisterMessage(PauseFeaturePipelineRequest)

ResumeFeaturePipelineResponse = _reflection.GeneratedProtocolMessageType('ResumeFeaturePipelineResponse', (_message.Message,), {
  'DESCRIPTOR' : _RESUMEFEATUREPIPELINERESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.featurepipeline.v1.featurepipeline_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.featurepipeline.v1.ResumeFeaturePipelineResponse)
  })
_sym_db.RegisterMessage(ResumeFeaturePipelineResponse)

ResumeFeaturePipelineRequest = _reflection.GeneratedProtocolMessageType('ResumeFeaturePipelineRequest', (_message.Message,), {
  'DESCRIPTOR' : _RESUMEFEATUREPIPELINEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.featurepipeline.v1.featurepipeline_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.featurepipeline.v1.ResumeFeaturePipelineRequest)
  })
_sym_db.RegisterMessage(ResumeFeaturePipelineRequest)

_FEATUREPIPELINESERVICE = DESCRIPTOR.services_by_name['FeaturePipelineService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z9github.com/metaprov/modelaapi/services/featurepipeline/v1'
  _LISTFEATUREPIPELINEREQUEST_LABELSENTRY._options = None
  _LISTFEATUREPIPELINEREQUEST_LABELSENTRY._serialized_options = b'8\001'
  _FEATUREPIPELINESERVICE.methods_by_name['ListFeaturePipelines']._options = None
  _FEATUREPIPELINESERVICE.methods_by_name['ListFeaturePipelines']._serialized_options = b'\202\323\344\223\002\"\022 /v1/featurepipelines/{namespace}'
  _FEATUREPIPELINESERVICE.methods_by_name['CreateFeaturePipeline']._options = None
  _FEATUREPIPELINESERVICE.methods_by_name['CreateFeaturePipeline']._serialized_options = b'\202\323\344\223\002\031\"\024/v1/featurepipelines:\001*'
  _FEATUREPIPELINESERVICE.methods_by_name['GetFeaturePipeline']._options = None
  _FEATUREPIPELINESERVICE.methods_by_name['GetFeaturePipeline']._serialized_options = b'\202\323\344\223\002)\022\'/v1/featurepipelines/{namespace}/{name}'
  _FEATUREPIPELINESERVICE.methods_by_name['UpdateFeaturePipeline']._options = None
  _FEATUREPIPELINESERVICE.methods_by_name['UpdateFeaturePipeline']._serialized_options = b'\202\323\344\223\002^\032Y/v1/featurepipelines/{featurepipeline.metadata.namespace}/{featurepipeline.metadata.name}:\001*'
  _FEATUREPIPELINESERVICE.methods_by_name['DeleteFeaturePipeline']._options = None
  _FEATUREPIPELINESERVICE.methods_by_name['DeleteFeaturePipeline']._serialized_options = b'\202\323\344\223\002)*\'/v1/featurepipelines/{namespace}/{name}'
  _FEATUREPIPELINESERVICE.methods_by_name['PauseFeaturePipeline']._options = None
  _FEATUREPIPELINESERVICE.methods_by_name['PauseFeaturePipeline']._serialized_options = b'\202\323\344\223\002/\"-/v1/featurepipelines/{namespace}/{name}:pause'
  _FEATUREPIPELINESERVICE.methods_by_name['ResumeFeaturePipeline']._options = None
  _FEATUREPIPELINESERVICE.methods_by_name['ResumeFeaturePipeline']._serialized_options = b'\202\323\344\223\002/\"-/v1/featurepipelines/{namespace}/{name}:pause'
  _LISTFEATUREPIPELINEREQUEST._serialized_start=277
  _LISTFEATUREPIPELINEREQUEST._serialized_end=543
  _LISTFEATUREPIPELINEREQUEST_LABELSENTRY._serialized_start=498
  _LISTFEATUREPIPELINEREQUEST_LABELSENTRY._serialized_end=543
  _LISTFEATUREPIPELINERESPONSE._serialized_start=546
  _LISTFEATUREPIPELINERESPONSE._serialized_end=701
  _CREATEFEATUREPIPELINEREQUEST._serialized_start=703
  _CREATEFEATUREPIPELINEREQUEST._serialized_end=829
  _CREATEFEATUREPIPELINERESPONSE._serialized_start=831
  _CREATEFEATUREPIPELINERESPONSE._serialized_end=862
  _UPDATEFEATUREPIPELINEREQUEST._serialized_start=865
  _UPDATEFEATUREPIPELINEREQUEST._serialized_end=1039
  _UPDATEFEATUREPIPELINERESPONSE._serialized_start=1041
  _UPDATEFEATUREPIPELINERESPONSE._serialized_end=1072
  _GETFEATUREPIPELINEREQUEST._serialized_start=1074
  _GETFEATUREPIPELINEREQUEST._serialized_end=1134
  _GETFEATUREPIPELINERESPONSE._serialized_start=1137
  _GETFEATUREPIPELINERESPONSE._serialized_end=1275
  _DELETEFEATUREPIPELINEREQUEST._serialized_start=1277
  _DELETEFEATUREPIPELINEREQUEST._serialized_end=1340
  _DELETEFEATUREPIPELINERESPONSE._serialized_start=1342
  _DELETEFEATUREPIPELINERESPONSE._serialized_end=1373
  _PAUSEFEATUREPIPELINERESPONSE._serialized_start=1375
  _PAUSEFEATUREPIPELINERESPONSE._serialized_end=1405
  _PAUSEFEATUREPIPELINEREQUEST._serialized_start=1407
  _PAUSEFEATUREPIPELINEREQUEST._serialized_end=1469
  _RESUMEFEATUREPIPELINERESPONSE._serialized_start=1471
  _RESUMEFEATUREPIPELINERESPONSE._serialized_end=1502
  _RESUMEFEATUREPIPELINEREQUEST._serialized_start=1504
  _RESUMEFEATUREPIPELINEREQUEST._serialized_end=1567
  _FEATUREPIPELINESERVICE._serialized_start=1570
  _FEATUREPIPELINESERVICE._serialized_end=3397
# @@protoc_insertion_point(module_scope)
