# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: github.com/metaprov/modelaapi/services/modelcompilerrun/v1/modelcompilerrun.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1 import generated_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_training_dot_v1alpha1_dot_generated__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nQgithub.com/metaprov/modelaapi/services/modelcompilerrun/v1/modelcompilerrun.proto\x12:github.com.metaprov.modelaapi.services.modelcompilerrun.v1\x1a google/protobuf/field_mask.proto\x1a\x1cgoogle/api/annotations.proto\x1aHgithub.com/metaprov/modelaapi/pkg/apis/training/v1alpha1/generated.proto\"\x8f\x02\n\x1cListModelCompilerRunsRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12t\n\x06labels\x18\x02 \x03(\x0b\x32\x64.github.com.metaprov.modelaapi.services.modelcompilerrun.v1.ListModelCompilerRunsRequest.LabelsEntry\x12\x11\n\tpage_size\x18\x03 \x01(\x05\x12\x12\n\npage_token\x18\x04 \x01(\t\x12\x10\n\x08order_by\x18\x05 \x01(\t\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xa3\x01\n\x1dListModelCompilerRunsResponse\x12i\n\x11modelcompilerruns\x18\x01 \x01(\x0b\x32N.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.ModelCompilerRunList\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\x1a\n\x18ModelCompilerRunResponse\"\x85\x01\n\x1d\x43reateModelCompilerRunRequest\x12\x64\n\x10modelcompilerrun\x18\x01 \x01(\x0b\x32J.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.ModelCompilerRun\" \n\x1e\x43reateModelCompilerRunResponse\"\xb5\x01\n\x1dUpdateModelCompilerRunRequest\x12\x64\n\x10modelcompilerrun\x18\x01 \x01(\x0b\x32J.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.ModelCompilerRun\x12.\n\nfield_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\" \n\x1eUpdateModelCompilerRunResponse\"=\n\x1aGetModelCompilerRunRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x91\x01\n\x1bGetModelCompilerRunResponse\x12\x64\n\x10modelcompilerrun\x18\x01 \x01(\x0b\x32J.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.ModelCompilerRun\x12\x0c\n\x04yaml\x18\x02 \x01(\t\"@\n\x1d\x44\x65leteModelCompilerRunRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\" \n\x1e\x44\x65leteModelCompilerRunResponse2\xc1\n\n\x17ModelCompilerRunService\x12\xf7\x01\n\x15ListModelCompilerRuns\x12X.github.com.metaprov.modelaapi.services.modelcompilerrun.v1.ListModelCompilerRunsRequest\x1aY.github.com.metaprov.modelaapi.services.modelcompilerrun.v1.ListModelCompilerRunsResponse\")\x82\xd3\xe4\x93\x02#\x12!/v1/modelcompilerruns/{namespace}\x12\xf1\x01\n\x16\x43reateModelCompilerRun\x12Y.github.com.metaprov.modelaapi.services.modelcompilerrun.v1.CreateModelCompilerRunRequest\x1aZ.github.com.metaprov.modelaapi.services.modelcompilerrun.v1.CreateModelCompilerRunResponse\" \x82\xd3\xe4\x93\x02\x1a\"\x15/v1/modelcompilerruns:\x01*\x12\xf8\x01\n\x13GetModelCompilerRun\x12V.github.com.metaprov.modelaapi.services.modelcompilerrun.v1.GetModelCompilerRunRequest\x1aW.github.com.metaprov.modelaapi.services.modelcompilerrun.v1.GetModelCompilerRunResponse\"0\x82\xd3\xe4\x93\x02*\x12(/v1/modelcompilerruns/{namespace}/{name}\x12\xb8\x02\n\x16UpdateModelCompilerRun\x12Y.github.com.metaprov.modelaapi.services.modelcompilerrun.v1.UpdateModelCompilerRunRequest\x1aZ.github.com.metaprov.modelaapi.services.modelcompilerrun.v1.UpdateModelCompilerRunResponse\"g\x82\xd3\xe4\x93\x02\x61\x1a\\/v1/modelcompilerruns/{modelcompilerrun.metadata.namespace}/{modelcompilerrun.metadata.name}:\x01*\x12\x81\x02\n\x16\x44\x65leteModelCompilerRun\x12Y.github.com.metaprov.modelaapi.services.modelcompilerrun.v1.DeleteModelCompilerRunRequest\x1aZ.github.com.metaprov.modelaapi.services.modelcompilerrun.v1.DeleteModelCompilerRunResponse\"0\x82\xd3\xe4\x93\x02**(/v1/modelcompilerruns/{namespace}/{name}B<Z:github.com/metaprov/modelaapi/services/modelcompilerrun/v1b\x06proto3')



_LISTMODELCOMPILERRUNSREQUEST = DESCRIPTOR.message_types_by_name['ListModelCompilerRunsRequest']
_LISTMODELCOMPILERRUNSREQUEST_LABELSENTRY = _LISTMODELCOMPILERRUNSREQUEST.nested_types_by_name['LabelsEntry']
_LISTMODELCOMPILERRUNSRESPONSE = DESCRIPTOR.message_types_by_name['ListModelCompilerRunsResponse']
_MODELCOMPILERRUNRESPONSE = DESCRIPTOR.message_types_by_name['ModelCompilerRunResponse']
_CREATEMODELCOMPILERRUNREQUEST = DESCRIPTOR.message_types_by_name['CreateModelCompilerRunRequest']
_CREATEMODELCOMPILERRUNRESPONSE = DESCRIPTOR.message_types_by_name['CreateModelCompilerRunResponse']
_UPDATEMODELCOMPILERRUNREQUEST = DESCRIPTOR.message_types_by_name['UpdateModelCompilerRunRequest']
_UPDATEMODELCOMPILERRUNRESPONSE = DESCRIPTOR.message_types_by_name['UpdateModelCompilerRunResponse']
_GETMODELCOMPILERRUNREQUEST = DESCRIPTOR.message_types_by_name['GetModelCompilerRunRequest']
_GETMODELCOMPILERRUNRESPONSE = DESCRIPTOR.message_types_by_name['GetModelCompilerRunResponse']
_DELETEMODELCOMPILERRUNREQUEST = DESCRIPTOR.message_types_by_name['DeleteModelCompilerRunRequest']
_DELETEMODELCOMPILERRUNRESPONSE = DESCRIPTOR.message_types_by_name['DeleteModelCompilerRunResponse']
ListModelCompilerRunsRequest = _reflection.GeneratedProtocolMessageType('ListModelCompilerRunsRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _LISTMODELCOMPILERRUNSREQUEST_LABELSENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.modelcompilerrun.v1.modelcompilerrun_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelcompilerrun.v1.ListModelCompilerRunsRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _LISTMODELCOMPILERRUNSREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelcompilerrun.v1.modelcompilerrun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelcompilerrun.v1.ListModelCompilerRunsRequest)
  })
_sym_db.RegisterMessage(ListModelCompilerRunsRequest)
_sym_db.RegisterMessage(ListModelCompilerRunsRequest.LabelsEntry)

ListModelCompilerRunsResponse = _reflection.GeneratedProtocolMessageType('ListModelCompilerRunsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTMODELCOMPILERRUNSRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelcompilerrun.v1.modelcompilerrun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelcompilerrun.v1.ListModelCompilerRunsResponse)
  })
_sym_db.RegisterMessage(ListModelCompilerRunsResponse)

ModelCompilerRunResponse = _reflection.GeneratedProtocolMessageType('ModelCompilerRunResponse', (_message.Message,), {
  'DESCRIPTOR' : _MODELCOMPILERRUNRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelcompilerrun.v1.modelcompilerrun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelcompilerrun.v1.ModelCompilerRunResponse)
  })
_sym_db.RegisterMessage(ModelCompilerRunResponse)

CreateModelCompilerRunRequest = _reflection.GeneratedProtocolMessageType('CreateModelCompilerRunRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEMODELCOMPILERRUNREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelcompilerrun.v1.modelcompilerrun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelcompilerrun.v1.CreateModelCompilerRunRequest)
  })
_sym_db.RegisterMessage(CreateModelCompilerRunRequest)

CreateModelCompilerRunResponse = _reflection.GeneratedProtocolMessageType('CreateModelCompilerRunResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATEMODELCOMPILERRUNRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelcompilerrun.v1.modelcompilerrun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelcompilerrun.v1.CreateModelCompilerRunResponse)
  })
_sym_db.RegisterMessage(CreateModelCompilerRunResponse)

UpdateModelCompilerRunRequest = _reflection.GeneratedProtocolMessageType('UpdateModelCompilerRunRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEMODELCOMPILERRUNREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelcompilerrun.v1.modelcompilerrun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelcompilerrun.v1.UpdateModelCompilerRunRequest)
  })
_sym_db.RegisterMessage(UpdateModelCompilerRunRequest)

UpdateModelCompilerRunResponse = _reflection.GeneratedProtocolMessageType('UpdateModelCompilerRunResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEMODELCOMPILERRUNRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelcompilerrun.v1.modelcompilerrun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelcompilerrun.v1.UpdateModelCompilerRunResponse)
  })
_sym_db.RegisterMessage(UpdateModelCompilerRunResponse)

GetModelCompilerRunRequest = _reflection.GeneratedProtocolMessageType('GetModelCompilerRunRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETMODELCOMPILERRUNREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelcompilerrun.v1.modelcompilerrun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelcompilerrun.v1.GetModelCompilerRunRequest)
  })
_sym_db.RegisterMessage(GetModelCompilerRunRequest)

GetModelCompilerRunResponse = _reflection.GeneratedProtocolMessageType('GetModelCompilerRunResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETMODELCOMPILERRUNRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelcompilerrun.v1.modelcompilerrun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelcompilerrun.v1.GetModelCompilerRunResponse)
  })
_sym_db.RegisterMessage(GetModelCompilerRunResponse)

DeleteModelCompilerRunRequest = _reflection.GeneratedProtocolMessageType('DeleteModelCompilerRunRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEMODELCOMPILERRUNREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelcompilerrun.v1.modelcompilerrun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelcompilerrun.v1.DeleteModelCompilerRunRequest)
  })
_sym_db.RegisterMessage(DeleteModelCompilerRunRequest)

DeleteModelCompilerRunResponse = _reflection.GeneratedProtocolMessageType('DeleteModelCompilerRunResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETEMODELCOMPILERRUNRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelcompilerrun.v1.modelcompilerrun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelcompilerrun.v1.DeleteModelCompilerRunResponse)
  })
_sym_db.RegisterMessage(DeleteModelCompilerRunResponse)

_MODELCOMPILERRUNSERVICE = DESCRIPTOR.services_by_name['ModelCompilerRunService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z:github.com/metaprov/modelaapi/services/modelcompilerrun/v1'
  _LISTMODELCOMPILERRUNSREQUEST_LABELSENTRY._options = None
  _LISTMODELCOMPILERRUNSREQUEST_LABELSENTRY._serialized_options = b'8\001'
  _MODELCOMPILERRUNSERVICE.methods_by_name['ListModelCompilerRuns']._options = None
  _MODELCOMPILERRUNSERVICE.methods_by_name['ListModelCompilerRuns']._serialized_options = b'\202\323\344\223\002#\022!/v1/modelcompilerruns/{namespace}'
  _MODELCOMPILERRUNSERVICE.methods_by_name['CreateModelCompilerRun']._options = None
  _MODELCOMPILERRUNSERVICE.methods_by_name['CreateModelCompilerRun']._serialized_options = b'\202\323\344\223\002\032\"\025/v1/modelcompilerruns:\001*'
  _MODELCOMPILERRUNSERVICE.methods_by_name['GetModelCompilerRun']._options = None
  _MODELCOMPILERRUNSERVICE.methods_by_name['GetModelCompilerRun']._serialized_options = b'\202\323\344\223\002*\022(/v1/modelcompilerruns/{namespace}/{name}'
  _MODELCOMPILERRUNSERVICE.methods_by_name['UpdateModelCompilerRun']._options = None
  _MODELCOMPILERRUNSERVICE.methods_by_name['UpdateModelCompilerRun']._serialized_options = b'\202\323\344\223\002a\032\\/v1/modelcompilerruns/{modelcompilerrun.metadata.namespace}/{modelcompilerrun.metadata.name}:\001*'
  _MODELCOMPILERRUNSERVICE.methods_by_name['DeleteModelCompilerRun']._options = None
  _MODELCOMPILERRUNSERVICE.methods_by_name['DeleteModelCompilerRun']._serialized_options = b'\202\323\344\223\002**(/v1/modelcompilerruns/{namespace}/{name}'
  _LISTMODELCOMPILERRUNSREQUEST._serialized_start=284
  _LISTMODELCOMPILERRUNSREQUEST._serialized_end=555
  _LISTMODELCOMPILERRUNSREQUEST_LABELSENTRY._serialized_start=510
  _LISTMODELCOMPILERRUNSREQUEST_LABELSENTRY._serialized_end=555
  _LISTMODELCOMPILERRUNSRESPONSE._serialized_start=558
  _LISTMODELCOMPILERRUNSRESPONSE._serialized_end=721
  _MODELCOMPILERRUNRESPONSE._serialized_start=723
  _MODELCOMPILERRUNRESPONSE._serialized_end=749
  _CREATEMODELCOMPILERRUNREQUEST._serialized_start=752
  _CREATEMODELCOMPILERRUNREQUEST._serialized_end=885
  _CREATEMODELCOMPILERRUNRESPONSE._serialized_start=887
  _CREATEMODELCOMPILERRUNRESPONSE._serialized_end=919
  _UPDATEMODELCOMPILERRUNREQUEST._serialized_start=922
  _UPDATEMODELCOMPILERRUNREQUEST._serialized_end=1103
  _UPDATEMODELCOMPILERRUNRESPONSE._serialized_start=1105
  _UPDATEMODELCOMPILERRUNRESPONSE._serialized_end=1137
  _GETMODELCOMPILERRUNREQUEST._serialized_start=1139
  _GETMODELCOMPILERRUNREQUEST._serialized_end=1200
  _GETMODELCOMPILERRUNRESPONSE._serialized_start=1203
  _GETMODELCOMPILERRUNRESPONSE._serialized_end=1348
  _DELETEMODELCOMPILERRUNREQUEST._serialized_start=1350
  _DELETEMODELCOMPILERRUNREQUEST._serialized_end=1414
  _DELETEMODELCOMPILERRUNRESPONSE._serialized_start=1416
  _DELETEMODELCOMPILERRUNRESPONSE._serialized_end=1448
  _MODELCOMPILERRUNSERVICE._serialized_start=1451
  _MODELCOMPILERRUNSERVICE._serialized_end=2796
# @@protoc_insertion_point(module_scope)
