# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: github.com/metaprov/modelaapi/services/objectstored/v1/objectstored.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1 import generated_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nIgithub.com/metaprov/modelaapi/services/objectstored/v1/objectstored.proto\x12\x36github.com.metaprov.modelaapi.services.objectstored.v1\x1a\x45github.com/metaprov/modelaapi/pkg/apis/infra/v1alpha1/generated.proto\"!\n\x0eIngestResponse\x12\x0f\n\x07liveKey\x18\x01 \x01(\t\"%\n\x0eObjectResponse\x12\x13\n\x0b\x61rchivePath\x18\x01 \x01(\t\"\xdb\x02\n\rObjectRequest\x12T\n\x06\x62ucket\x18\x01 \x01(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.VirtualBucket\x12U\n\nconnection\x18\x02 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Connection\x12\x61\n\x06secret\x18\x06 \x03(\x0b\x32Q.github.com.metaprov.modelaapi.services.objectstored.v1.ObjectRequest.SecretEntry\x12\x0b\n\x03key\x18\x07 \x01(\t\x1a-\n\x0bSecretEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x0c:\x02\x38\x01\"-\n\x1c\x45xistInVirtualBucketResponse\x12\r\n\x05\x65xist\x18\x01 \x01(\x08\x32\xa2\x05\n\x12ObjectstoreService\x12\x99\x01\n\x06Ingest\x12\x45.github.com.metaprov.modelaapi.services.objectstored.v1.ObjectRequest\x1a\x46.github.com.metaprov.modelaapi.services.objectstored.v1.ObjectResponse\"\x00\x12\x9a\x01\n\x07\x41rchive\x12\x45.github.com.metaprov.modelaapi.services.objectstored.v1.ObjectRequest\x1a\x46.github.com.metaprov.modelaapi.services.objectstored.v1.ObjectResponse\"\x00\x12\x9a\x01\n\x07Recover\x12\x45.github.com.metaprov.modelaapi.services.objectstored.v1.ObjectRequest\x1a\x46.github.com.metaprov.modelaapi.services.objectstored.v1.ObjectResponse\"\x00\x12\xb5\x01\n\x14\x45xistInVirtualBucket\x12\x45.github.com.metaprov.modelaapi.services.objectstored.v1.ObjectRequest\x1aT.github.com.metaprov.modelaapi.services.objectstored.v1.ExistInVirtualBucketResponse\"\x00\x42\x38Z6github.com/metaprov/modelaapi/services/objectstored/v1b\x06proto3')



_INGESTRESPONSE = DESCRIPTOR.message_types_by_name['IngestResponse']
_OBJECTRESPONSE = DESCRIPTOR.message_types_by_name['ObjectResponse']
_OBJECTREQUEST = DESCRIPTOR.message_types_by_name['ObjectRequest']
_OBJECTREQUEST_SECRETENTRY = _OBJECTREQUEST.nested_types_by_name['SecretEntry']
_EXISTINVIRTUALBUCKETRESPONSE = DESCRIPTOR.message_types_by_name['ExistInVirtualBucketResponse']
IngestResponse = _reflection.GeneratedProtocolMessageType('IngestResponse', (_message.Message,), {
  'DESCRIPTOR' : _INGESTRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.objectstored.v1.objectstored_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.objectstored.v1.IngestResponse)
  })
_sym_db.RegisterMessage(IngestResponse)

ObjectResponse = _reflection.GeneratedProtocolMessageType('ObjectResponse', (_message.Message,), {
  'DESCRIPTOR' : _OBJECTRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.objectstored.v1.objectstored_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.objectstored.v1.ObjectResponse)
  })
_sym_db.RegisterMessage(ObjectResponse)

ObjectRequest = _reflection.GeneratedProtocolMessageType('ObjectRequest', (_message.Message,), {

  'SecretEntry' : _reflection.GeneratedProtocolMessageType('SecretEntry', (_message.Message,), {
    'DESCRIPTOR' : _OBJECTREQUEST_SECRETENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.objectstored.v1.objectstored_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.objectstored.v1.ObjectRequest.SecretEntry)
    })
  ,
  'DESCRIPTOR' : _OBJECTREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.objectstored.v1.objectstored_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.objectstored.v1.ObjectRequest)
  })
_sym_db.RegisterMessage(ObjectRequest)
_sym_db.RegisterMessage(ObjectRequest.SecretEntry)

ExistInVirtualBucketResponse = _reflection.GeneratedProtocolMessageType('ExistInVirtualBucketResponse', (_message.Message,), {
  'DESCRIPTOR' : _EXISTINVIRTUALBUCKETRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.objectstored.v1.objectstored_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.objectstored.v1.ExistInVirtualBucketResponse)
  })
_sym_db.RegisterMessage(ExistInVirtualBucketResponse)

_OBJECTSTORESERVICE = DESCRIPTOR.services_by_name['ObjectstoreService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z6github.com/metaprov/modelaapi/services/objectstored/v1'
  _OBJECTREQUEST_SECRETENTRY._options = None
  _OBJECTREQUEST_SECRETENTRY._serialized_options = b'8\001'
  _INGESTRESPONSE._serialized_start=204
  _INGESTRESPONSE._serialized_end=237
  _OBJECTRESPONSE._serialized_start=239
  _OBJECTRESPONSE._serialized_end=276
  _OBJECTREQUEST._serialized_start=279
  _OBJECTREQUEST._serialized_end=626
  _OBJECTREQUEST_SECRETENTRY._serialized_start=581
  _OBJECTREQUEST_SECRETENTRY._serialized_end=626
  _EXISTINVIRTUALBUCKETRESPONSE._serialized_start=628
  _EXISTINVIRTUALBUCKETRESPONSE._serialized_end=673
  _OBJECTSTORESERVICE._serialized_start=676
  _OBJECTSTORESERVICE._serialized_end=1350
# @@protoc_insertion_point(module_scope)
