# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from github.com.metaprov.modelaapi.services.webrequestrun.v1 import webrequestrun_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_webrequestrun_dot_v1_dot_webrequestrun__pb2


class WebRequestRunServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.ListWebRequestRuns = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.webrequestrun.v1.WebRequestRunService/ListWebRequestRuns',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_webrequestrun_dot_v1_dot_webrequestrun__pb2.ListWebRequestRunsRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_webrequestrun_dot_v1_dot_webrequestrun__pb2.ListWebRequestRunsResponse.FromString,
                )
        self.CreateWebRequestRun = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.webrequestrun.v1.WebRequestRunService/CreateWebRequestRun',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_webrequestrun_dot_v1_dot_webrequestrun__pb2.CreateWebRequestRunRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_webrequestrun_dot_v1_dot_webrequestrun__pb2.CreateWebRequestRunResponse.FromString,
                )
        self.GetWebRequestRun = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.webrequestrun.v1.WebRequestRunService/GetWebRequestRun',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_webrequestrun_dot_v1_dot_webrequestrun__pb2.GetWebRequestRunRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_webrequestrun_dot_v1_dot_webrequestrun__pb2.GetWebRequestRunResponse.FromString,
                )
        self.UpdateWebRequestRun = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.webrequestrun.v1.WebRequestRunService/UpdateWebRequestRun',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_webrequestrun_dot_v1_dot_webrequestrun__pb2.UpdateWebRequestRunRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_webrequestrun_dot_v1_dot_webrequestrun__pb2.UpdateWebRequestRunResponse.FromString,
                )
        self.DeleteWebRequestRun = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.webrequestrun.v1.WebRequestRunService/DeleteWebRequestRun',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_webrequestrun_dot_v1_dot_webrequestrun__pb2.DeleteWebRequestRunRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_webrequestrun_dot_v1_dot_webrequestrun__pb2.DeleteWebRequestRunResponse.FromString,
                )


class WebRequestRunServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def ListWebRequestRuns(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateWebRequestRun(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetWebRequestRun(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateWebRequestRun(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteWebRequestRun(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_WebRequestRunServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'ListWebRequestRuns': grpc.unary_unary_rpc_method_handler(
                    servicer.ListWebRequestRuns,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_webrequestrun_dot_v1_dot_webrequestrun__pb2.ListWebRequestRunsRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_webrequestrun_dot_v1_dot_webrequestrun__pb2.ListWebRequestRunsResponse.SerializeToString,
            ),
            'CreateWebRequestRun': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateWebRequestRun,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_webrequestrun_dot_v1_dot_webrequestrun__pb2.CreateWebRequestRunRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_webrequestrun_dot_v1_dot_webrequestrun__pb2.CreateWebRequestRunResponse.SerializeToString,
            ),
            'GetWebRequestRun': grpc.unary_unary_rpc_method_handler(
                    servicer.GetWebRequestRun,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_webrequestrun_dot_v1_dot_webrequestrun__pb2.GetWebRequestRunRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_webrequestrun_dot_v1_dot_webrequestrun__pb2.GetWebRequestRunResponse.SerializeToString,
            ),
            'UpdateWebRequestRun': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateWebRequestRun,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_webrequestrun_dot_v1_dot_webrequestrun__pb2.UpdateWebRequestRunRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_webrequestrun_dot_v1_dot_webrequestrun__pb2.UpdateWebRequestRunResponse.SerializeToString,
            ),
            'DeleteWebRequestRun': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteWebRequestRun,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_webrequestrun_dot_v1_dot_webrequestrun__pb2.DeleteWebRequestRunRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_webrequestrun_dot_v1_dot_webrequestrun__pb2.DeleteWebRequestRunResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'github.com.metaprov.modelaapi.services.webrequestrun.v1.WebRequestRunService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class WebRequestRunService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def ListWebRequestRuns(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.webrequestrun.v1.WebRequestRunService/ListWebRequestRuns',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_webrequestrun_dot_v1_dot_webrequestrun__pb2.ListWebRequestRunsRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_webrequestrun_dot_v1_dot_webrequestrun__pb2.ListWebRequestRunsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateWebRequestRun(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.webrequestrun.v1.WebRequestRunService/CreateWebRequestRun',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_webrequestrun_dot_v1_dot_webrequestrun__pb2.CreateWebRequestRunRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_webrequestrun_dot_v1_dot_webrequestrun__pb2.CreateWebRequestRunResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetWebRequestRun(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.webrequestrun.v1.WebRequestRunService/GetWebRequestRun',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_webrequestrun_dot_v1_dot_webrequestrun__pb2.GetWebRequestRunRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_webrequestrun_dot_v1_dot_webrequestrun__pb2.GetWebRequestRunResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateWebRequestRun(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.webrequestrun.v1.WebRequestRunService/UpdateWebRequestRun',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_webrequestrun_dot_v1_dot_webrequestrun__pb2.UpdateWebRequestRunRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_webrequestrun_dot_v1_dot_webrequestrun__pb2.UpdateWebRequestRunResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteWebRequestRun(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.webrequestrun.v1.WebRequestRunService/DeleteWebRequestRun',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_webrequestrun_dot_v1_dot_webrequestrun__pb2.DeleteWebRequestRunRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_webrequestrun_dot_v1_dot_webrequestrun__pb2.DeleteWebRequestRunResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
